@@ -1,5 +1,5 @@
 ;;; dtk-speak.el --- Provides Emacs Lisp interface to speech server
-;;;$Id: dtk-speak.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;;$Id: dtk-speak.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacs interface to TTS
 ;;; Keywords: Dectalk Emacs Elisp
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -57,12 +57,33 @@
 (require 'custom)
 (require 'dtk-interp)
 (require 'dtk-unicode)
-(require 'dectalk-voices)
-(require 'outloud-voices)
-(require 'multispeech-voices)
+
 (require 'espeak-voices)
 (require 'flite-voices)
 
+;;}}}
+;;{{{ Forward Declarations:
+(declare-function emacspeak-auditory-icon "emacspeak-sounds.el" (icon))
+(declare-function emacspeak-queue-auditory-icon "emacspeak-sounds.el" (icon))
+;;;###autoload 
+(defvar dtk-program
+  (or  (getenv "DTK_PROGRAM" ) "dtk-exp")
+  "The program to use to talk to the speech engine.
+Possible choices at present:
+dtk-exp     For the Dectalk Express.
+dtk-mv      for the Multivoice and older Dectalks.
+outloud     For IBM ViaVoice Outloud
+multispeech For Multilingual speech server
+espeak      For eSpeak
+The default is dtk-exp.")
+
+(defvar emacspeak-pronounce-pronunciation-table)
+(defvar emacspeak-ssh-tts-server )
+(defvar emacspeak-auditory-icon-function )
+(defvar emacspeak-directory )
+(defvar emacspeak-use-auditory-icons )
+(defvar emacspeak-pronounce-pronunciation-personality )
+
 ;;}}}
 ;;{{{  user customizations:
 
@@ -78,22 +99,17 @@ Particularly useful for web browsing."
   :group  'dtk
   :group  'tts)
 (make-variable-buffer-local 'tts-strip-octals)
+
 ;;;###autoload
-(defcustom dtk-stop-immediately-while-typing t
-  "*Set it to nil if you dont want speech to flush as you
-type.  You can use command
-`dtk-toggle-stop-immediately-while-typing' bound to
-\\[dtk-toggle-stop-immediately-while-typing] to toggle this setting."
-  :group 'tts
-  :type 'boolean)
-(make-variable-buffer-local 'dtk-stop-immediately-while-typing)
 ;;;###autoload
-(defcustom dtk-speech-rate-base 50
+(defcustom dtk-speech-rate-base
+  (if (string-match "dtk" dtk-program) 180 50)
   "*Value of lowest tolerable speech rate."
   :type 'integer
   :group 'tts)
 ;;;###autoload
-(defcustom dtk-speech-rate-step 50
+(defcustom dtk-speech-rate-step
+  (if (string-match "dtk" dtk-program) 50 8)
   "*Value of speech rate increment.
 This determines step size used when setting speech rate via command
 `dtk-set-predefined-speech-rate'.  Formula used is
@@ -108,17 +124,6 @@ hook."
   :type 'hook
   :group 'tts)
 
-(defvar dtk-program
-  (or  (getenv "DTK_PROGRAM" ) "dtk-exp")
-  "The program to use to talk to the speech engine.
-Possible choices at present:
-dtk-exp     For the Dectalk Express.
-dtk-mv      for the Multivoice and older Dectalks.
-outloud     For IBM ViaVoice Outloud
-multispeech For Multilingual speech server
-espeak      For eSpeak
-The default is dtk-exp.")
-
 (defvar dtk-quiet nil
   "Switch indicating if the speech synthesizer is to keep quiet.
 Do not set this variable by hand.
@@ -174,7 +179,9 @@ split caps Do not set this variable by hand, use command
 (defvar dtk-last-output nil
   "Variable holding last output.")
 
-(defvar dtk-speech-rate 225
+(defvar dtk-speech-rate
+  (if (string-match "dtk" dtk-program)
+      225 100)
   "Rate at which tts talks.
 Do not modify this variable directly; use command  `dtk-set-rate'
  bound to \\[dtk-set-rate].")
@@ -331,10 +338,7 @@ Optional argument FORCE  flushes the command to the speech server."
   (interactive "sEnter new language: \n")
   (declare (special dtk-quiet dtk-speaker-process
                     dtk-speak-server-initialized))
-  ;;  (unless dtk-quiet
-  (when dtk-speak-server-initialized
-    (dtk-interp-language lang (interactive-p))))
-;;)
+  (when dtk-speak-server-initialized (dtk-interp-language lang (interactive-p))))
 
 (defun dtk-set-next-language ()
   "Switch to the next available language"
@@ -386,8 +390,9 @@ will set \"en_GB\".
 ;;;  [] marks dtk commands; {} is special to tcl
 ;;; Optionally post-process the text with cleanup function if one is specified.
 (defconst dtk-bracket-regexp
-  "[][{}<>\\|`#]"
+  "[][{}<>\\|`#\n]"
   "Brackets and other chars  that are special to dtk and tcl.
+Newlines  become spaces so each server request is a single line.
 {} is special to tcl.
 [] is special to both dtk and tcl.
 <> and | are fixed to improve pronunciation.
@@ -402,7 +407,7 @@ will set \"en_GB\".
 
 (defsubst  dtk-fix-brackets (mode)
   "Quote any delimiters that need special treatment.
-Argument MODE  specifies the current pronunciation mode."
+Argument MODE  specifies the current pronunciation mode --- See \\[dtk-bracket-regexp]"
   (declare  (special dtk-bracket-regexp ))
   (let ((inhibit-read-only t))
     (goto-char (point-min))
@@ -416,6 +421,8 @@ Argument MODE  specifies the current pronunciation mode."
                 (get-text-property
                  start 'personality))
           (cond
+           ((= 10  (char-after (match-beginning 0 ))) ; newline
+            (replace-match " "))
            ((= ?| (char-after (match-beginning 0 )))
             (replace-match " pipe "))
            ((= ?< (char-after (match-beginning 0 )))
@@ -442,6 +449,7 @@ Argument MODE  specifies the current pronunciation mode."
      (t
       (while (re-search-forward dtk-bracket-regexp   nil t )
         (replace-match " " nil t ))))))
+
 ;;;###autoload
 (defcustom dtk-speak-nonprinting-chars nil
   "*Option that specifies handling of non-printing chars.
@@ -631,15 +639,6 @@ Argument COMPLEMENT  is the complement of separator."
 ;;; causes the sound
 ;;; to be queued.
 
-(defsubst tts-get-overlay-personality (position)
-  "Return personality at the front of the overlay list at position."
-  (car
-   (delete nil
-           (mapcar
-            #'(lambda (o)
-                (overlay-get o 'personality))
-            (overlays-at position)))))
-
 (defsubst tts-get-overlay-auditory-icon (position)
   "Return auditory icon  at the front of the overlay list at position."
   (car
@@ -649,6 +648,15 @@ Argument COMPLEMENT  is the complement of separator."
                 (overlay-get o 'auditory-icon))
             (overlays-at position)))))
 
+(defsubst tts-get-overlay-personality (position)
+  "Return personality at the front of the overlay list at position."
+  (car
+   (delete nil
+           (mapcar
+            #'(lambda (o)
+                (overlay-get o 'personality))
+            (overlays-at position)))))
+
 (defsubst next-true-single-property-change (start  prop object  limit)
   "Similar to next-single-property-change, but compares property values with equal if they are not atoms."
   (let ((initial-value (get-text-property start  prop object)))
@@ -812,8 +820,6 @@ current local  value to the result."
       (setq dtk-speech-rate rate))
      (t (setq dtk-speech-rate rate)))
     (dtk-interp-set-rate rate)
-    (when prefix
-      (tts-configure-synthesis-setup dtk-program))
     (when (interactive-p)
       (message "Set speech rate to %s %s"
                rate
@@ -847,9 +853,8 @@ speech rate:")))
             (* dtk-speech-rate-step  level ))
          prefix )
         (when (interactive-p)
-          (message "Set speech rate to level %s %s"
-                   level
-                   (if prefix " globaly " " locally ")))))))
+          (message "Set speech rate to level %s"
+                   level))))))
 
 ;;;###autoload
 (defun dtk-set-character-scale (factor &optional prefix)
@@ -880,13 +885,6 @@ current local  value to the result."
 Turning on this switch silences speech.
 Optional interactive prefix arg causes this setting to become global.")
 
-(ems-generate-switcher 'dtk-toggle-stop-immediately-while-typing
-                       'dtk-stop-immediately-while-typing
-                       "Toggle state of variable `dtk-stop-immediately-while-typing'.
-As the name implies, if T then speech flushes immediately as you
-type.  Optional argument PREFIX specifies if the setting applies
-to all buffers.")
-
 (ems-generate-switcher 'dtk-toggle-split-caps
                        'dtk-split-caps
                        "Toggle split caps mode.
@@ -1015,31 +1013,19 @@ Typically used after the Dectalk has been power   cycled."
   "Records if speech has been paused.")
 
 ;;;###autoload
-(defun dtk-pause (&optional prefix)
-  "Pause ongoing speech.
-The speech can be resumed with command `dtk-resume'
-normally bound to \\[dtk-resume].  Pausing speech is useful when one needs to
-perform a few actions before continuing to read a large document.  Emacspeak
-gives you speech feedback as usual once speech has been paused.  `dtk-resume'
-continues the interrupted speech irrespective of the buffer
-in which it is executed.
-Optional PREFIX arg flushes any previously paused speech."
-  (interactive "P")
+(defun dtk-pause ()
+  "Temporarily pause / rsume speech."
+  (interactive)
   (declare (special dtk-paused))
   (cond
    ((not dtk-paused)
     (dtk-interp-pause)
     (setq dtk-paused t)
     (emacspeak-auditory-icon 'button))
-   ((and (interactive-p)
-         prefix
-         dtk-paused)
-    (dtk-interp-pause)
-    (dtk-speak "Flushed previously paused speech ")
-    (setq dtk-paused t))
-   ((and dtk-paused
-         (interactive-p))
-    (emacspeak-auditory-icon 'warn-user))))
+   (t
+    (setq dtk-paused nil)
+    (dtk-interp-resume))))
+
 ;;;###autoload
 (defcustom dtk-resume-should-toggle t
   "*T means `dtk-resume' acts as a toggle."
@@ -1534,37 +1520,101 @@ This is setup on a per engine basis.")
 
 ;;; will be reset on a per TTS engine basis.
 (defalias 'tts-get-voice-command 'dectalk-get-voice-command)
-
+;;;###autoload
 (defun tts-configure-synthesis-setup (&optional tts-name)
   "Setup synthesis environment. "
   (declare (special dtk-program emacspeak-auditory-icon-function
                     tts-voice-reset-code))
   (unless tts-name (setq tts-name dtk-program))
   (cond
-   ((string-match "outloud" tts-name)
-    (outloud-configure-tts))
-   ((string-match "multispeech" tts-name)
-    (multispeech-configure-tts))
-   ((string-match "espeak" tts-name)
-    (espeak-configure-tts))
-   ((string-match "dtk-" tts-name)      ;all dectalks
-    (dectalk-configure-tts))
-   ((string-match "eflite" tts-name)
-    (flite-configure-tts))
-   (t (dectalk-configure-tts)           ; will become
-                                        ; generic-configure)))
-      ))
+                                        ;viavoice outloud family 
+   ((string-match "outloud" tts-name) (outloud-configure-tts))
+                                        ;all dectalks
+   ((string-match "dtk-" tts-name) (dectalk-configure-tts))
+   ((string-match "^multispeech$" tts-name) (multispeech-configure-tts))
+                                        ;exact match
+   ((string-match "^mac$" tts-name) (mac-configure-tts))
+                                        ; exact match
+   ((string-match "^espeak$" tts-name) (espeak-configure-tts))
+   ((string-match "^eflite$" tts-name) (flite-configure-tts))
+                                        ; generic configure
+   (t (plain-configure-tts)))
   (when (string-match "^ssh" tts-name)  ;remote server
     (setq emacspeak-auditory-icon-function 'emacspeak-serve-auditory-icon))
   (load-library "voice-setup")
   (setq tts-voice-reset-code (tts-get-voice-command tts-default-voice)))
 
-;;; forward declaration.
+(defvar tts-device "default"
+  "Name of current sound device in use.")
+
 ;;;###autoload
-(defun dtk-select-server (program )
+(defun dtk-select-server (program &optional device)
   "Select a speech server interactively.
-Argument PROGRAM specifies the speech server program.
-When called  interactively, The selected server is started immediately. "
+Argument PROGRAM specifies the speech server program. When called
+interactively, The selected server is started
+immediately. Optional arg device sets up environment variable
+ALSA_DEFAULT to specified device before starting the server."
+  (interactive
+   (list
+    (completing-read
+     "Select speech server:"
+     (or dtk-servers-alist
+         (tts-setup-servers-alist))
+     nil
+     t  )
+    current-prefix-arg))
+  (declare (special   dtk-program dtk-servers-alist
+                      tts-device emacspeak-servers-directory
+                      emacspeak-ssh-tts-server))
+  (when (and (interactive-p) device)
+    (setq tts-device (read-from-minibuffer "ALSA_DEFAULT: ")))
+  (setenv "ALSA_DEFAULT" tts-device)
+  (let ((ssh-server (format "ssh-%s" dtk-program)))
+    (setq dtk-program program)
+    (when (file-exists-p (expand-file-name ssh-server emacspeak-servers-directory))
+      (setq emacspeak-ssh-tts-server ssh-server)
+      (setq-default emacspeak-ssh-tts-server ssh-server))
+    (when (interactive-p)
+      (dtk-initialize))))
+
+(defcustom tts-device-list (list "default")
+  "List of ALSA sound devices  we can use."
+  :type '(repeat
+          (choice :tag "Device"
+                  (const   "default")
+                  (const   "$ALSA_DEFAULT")
+                  (string )))
+  :group 'dtk)
+
+;;;###autoload
+(defun tts-cycle-device (&optional restart)
+  "Cycle through available ALSA devices.
+Optional interactive prefix arg restarts current TTS server."
+  (interactive "P")
+  (declare (special tts-device tts-device-list))
+  (let ((pos (position tts-device tts-device-list :test
+                       #'string=))
+        (len (length tts-device-list)))
+    (cond
+     ((= len 1) (message "Only  one ALSA device."))
+     (t                                 ; Cycle
+      (setq tts-device
+            (nth
+             (% (+ 1 pos) len)
+             tts-device-list))
+      (setenv "ALSA_DEFAULT" tts-device)
+      (message "ALSA_DEFAULT: %s" tts-device)
+      (when current-prefix-arg (tts-restart))))))
+
+(defvar dtk-async-server-process nil
+  "Process handle to async server.")
+
+;;;###autoload
+(defun dtk-async-server (program)
+  "Select and start an async  speech server interactively.
+Async servers allow external programs like self-voicing Web browsers to use
+the Emacspeak TTS server abstraction.
+Argument PROGRAM specifies the speech server program."
   (interactive
    (list
     (completing-read
@@ -1573,16 +1623,68 @@ When called  interactively, The selected server is started immediately. "
          (tts-setup-servers-alist))
      nil
      t  )))
-  (declare (special   dtk-program dtk-servers-alist
-                      emacspeak-servers-directory emacspeak-ssh-tts-server))
-  (let ((ssh-server (format "ssh-%s" dtk-program)))
-    (setq dtk-program program)
-    (tts-configure-synthesis-setup dtk-program)
-    (when (file-exists-p (expand-file-name ssh-server emacspeak-servers-directory))
-      (setq emacspeak-ssh-tts-server ssh-server)
-      (setq-default emacspeak-ssh-tts-server ssh-server))
-    (when (interactive-p)
-      (dtk-initialize))))
+  (declare (special    dtk-servers-alist
+                       dtk-async-server-process emacspeak-servers-directory ))
+  (when (and
+         dtk-async-server-process
+         (eq 'run (process-status dtk-async-server-process)))
+    (kill-process dtk-async-server-process))
+  (setq dtk-async-server-process
+        (start-process
+         "AsyncTTS"
+         "*AsyncTTS*"
+         (executable-find "python")
+         (expand-file-name "python/HTTPSpeaker.py" emacspeak-servers-directory)
+         program)))
+
+;;;###autoload
+(defvar dtk-local-server-process nil
+  "Local server process.")
+
+;;;###autoload
+(defcustom dtk-speech-server-program "speech-server"
+  "Local speech server script."
+  :type '(choice :tag "Local Server: "
+                 (const :tag "32 Bit" "32-speech-server")
+                 (const :tag "Default" "speech-server"))
+  :group 'dtk)
+(defvar dtk-local-server-port "2222"
+  "Port where we run our local server.")
+
+(defcustom dtk-local-engine "outloud"
+  "Engine we use  for our local TTS  server."
+  :type '(choice
+          (const :tag "Dectalk Express" "dtk-exp")
+          (const :tag "Viavoice Outloud" "outloud")
+          (const :tag "32Bit ViaVoice on 64Bit Linux" "32-outloud"))
+  :group 'dtk)
+
+(defun dtk-local-server (program)
+  "Select and start an local  speech server interactively.
+Local server lets Emacspeak on a remote host connect back via SSH  port forwarding for instance.
+Argument PROGRAM specifies the speech server program.
+Port  defaults to  dtk-local-server-port"
+  (interactive
+   (list
+    (completing-read
+     "Select speech server:"
+     (or dtk-servers-alist
+         (tts-setup-servers-alist))
+     nil
+     t  )))
+  (declare (special    dtk-servers-alist dtk-local-server-port
+                       dtk-local-server-process emacspeak-servers-directory ))
+  (when (and
+         dtk-local-server-process
+         (eq 'run (process-status dtk-local-server-process)))
+    (kill-process dtk-async-server-process))
+  (setq dtk-local-server-process
+        (start-process
+         "LocalTTS"
+         "*localTTS*"
+         (expand-file-name  dtk-speech-server-program emacspeak-servers-directory)
+         dtk-local-server-port
+         (expand-file-name program  emacspeak-servers-directory))))
 
 ;;}}}
 ;;{{{  initialize the speech process
@@ -1609,15 +1711,12 @@ Default is to use pipes.")
                     dtk-speak-server-initialized
                     dtk-startup-hook emacspeak-servers-directory))
   (let ((new-process nil)
-        (process-connection-type  dtk-speak-process-connection-type)
-        (dtk-program (expand-file-name dtk-program
-                                       emacspeak-servers-directory)))
+        (process-connection-type  dtk-speak-process-connection-type))
     (setq new-process
           (start-process
            "speaker"
            (and dtk-debug tts-debug-buffer)
-           (expand-file-name dtk-program
-                             emacspeak-servers-directory)))
+           (expand-file-name dtk-program emacspeak-servers-directory)))
     (setq dtk-speak-server-initialized
           (or (eq 'run (process-status new-process ))
               (eq 'open (process-status new-process))))
@@ -1631,7 +1730,6 @@ Default is to use pipes.")
         (delete-process dtk-speaker-process ))
       (setq dtk-speaker-process new-process)
       (set-process-coding-system dtk-speaker-process 'utf-8 'utf-8)
-      (tts-configure-synthesis-setup dtk-program)
       (run-hooks 'dtk-startup-hook ))
      (t
       (when (interactive-p)
@@ -1703,11 +1801,9 @@ No-op if variable `dtk-quiet' is set to t.
 If option `outline-minor-mode' is on and selective display is in effect,
 only speak upto the first ctrl-m."
   (declare (special dtk-speaker-process dtk-stop-immediately
-                    tts-strip-octals
-                    inhibit-point-motion-hooks
+                    tts-strip-octals inhibit-point-motion-hooks
                     dtk-speak-server-initialized emacspeak-use-auditory-icons
-                    dtk-speech-rate
-                    dtk-speak-nonprinting-chars
+                    dtk-speech-rate dtk-speak-nonprinting-chars
                     dtk-speak-treat-embedded-punctuations-specially
                     dtk-quiet  dtk-chunk-separator-syntax
                     voice-lock-mode   dtk-punctuation-mode
