@@ -1,5 +1,5 @@
 ;;; emacspeak-advice.el --- Advice all core Emacs functionality to speak intelligently
-;;; $Id: emacspeak-advice.el 6563 2010-08-16 02:47:30Z tv.raman.tv $
+;;; $Id: emacspeak-advice.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Core advice forms that make emacspeak work
 ;;; Keywords: Emacspeak, Speech, Advice, Spoken  output
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1995, 1996,  1997 by T. V. Raman
 ;;; All Rights Reserved.
 ;;;
@@ -74,6 +74,10 @@
 (require 'dtk-speak)
 (require 'emacspeak-speak)
 (require 'emacspeak-sounds)
+(require 'ansi-color)
+;;}}}
+;;{{{ Forward Declarations:
+(defvar emacspeak-prefix)
 
 ;;}}}
 ;;{{{ Advice ding
@@ -256,7 +260,7 @@ If you moved more than a line,
   "Speak the screenful."
   (when (interactive-p)
     (emacspeak-auditory-icon 'scroll)
-    (dtk-speak (emacspeak-get-window-contents))))e
+    (dtk-speak (emacspeak-get-window-contents))))
 (defadvice scroll-up-command (after emacspeak pre act comp)
   "Speak the next screenful."
   (when (interactive-p)
@@ -382,7 +386,6 @@ the words that were capitalized."
    (t ad-do-it))
   ad-return-value)
 
-
 (defadvice ucs-insert (after emacspeak pre act comp)
   "Speak char we inserted."
   (emacspeak-speak-char-name (ad-get-arg 0)))
@@ -486,6 +489,28 @@ the words that were capitalized."
        (  thisblank (message "Deleting surrounding  blank lines"))
        (t (message "Deleting possible subsequent blank lines"))))))
 
+;;}}}
+;;{{{  Advice PComplete 
+
+(defadvice pcomplete-list (after emacspeak pre act )
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'help)
+    (emacspeak-auditory-icon 'help)))
+
+(defadvice pcomplete-show-completions (around emacspeak pre act comp)
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
+
+(defadvice pcomplete (around emacspeak pre act)
+  "Say what you completed."
+  (let ((orig (point)))
+    ad-do-it
+    (when  (interactive-p)
+      (emacspeak-speak-region orig (point))
+      (emacspeak-auditory-icon 'complete))
+    ad-return-value))
+
 ;;}}}
 ;;{{{  advice insertion commands to speak.
 
@@ -493,18 +518,24 @@ the words that were capitalized."
   "Speak what was completed."
   (declare (special emacspeak-word-echo))
   (when (and emacspeak-word-echo  (interactive-p ))
-    (condition-case nil
-        (save-excursion
-          (skip-syntax-backward " ")
-          (backward-char 1)
-          (emacspeak-speak-word))
-      (error nil ))))
+    (let ((display (get-char-property (1- (point)) 'display)))
+      (if display
+          (dtk-say display)
+        (condition-case nil
+            (save-excursion
+              (skip-syntax-backward " ")
+              (backward-char 1)
+              (emacspeak-speak-word))
+          (error nil ))))))
 
 (defadvice completion-separator-self-insert-command (after emacspeak act comp)
   "Speak char after inserting it."
   (declare (special emacspeak-character-echo))
   (when (and emacspeak-character-echo  (interactive-p))
-    (emacspeak-speak-this-char (preceding-char ))))
+    (let ((display (get-char-property (1- (point)) 'display)))
+      (if display
+          (dtk-say display)
+        (emacspeak-speak-this-char (preceding-char ))))))
 
 (defadvice quoted-insert  (after emacspeak pre act )
   "Speak the character that was inserted."
@@ -590,15 +621,15 @@ before the message is spoken."
                     emacspeak-speak-messages emacspeak-lazy-message-time))
   (let ((inhibit-read-only t))
     ad-do-it
-    (setq emacspeak-last-message ad-return-value )
     (when (and
-           emacspeak-speak-messages     ; speaking messages
-           ad-return-value              ;we really do have a message
+           (current-message)
+           emacspeak-speak-messages  ; speaking messages
            (/= emacspeak-lazy-message-time ;; previous message not recent
                (setq emacspeak-lazy-message-time (nth 1  (current-time)))))
+      (setq emacspeak-last-message  (ansi-color-apply (current-message)))
       ;; so we really need to speak it
       (tts-with-punctuations 'all
-                             (dtk-speak ad-return-value)))
+                             (dtk-speak emacspeak-last-message)))
     ad-return-value))
 
 (defvar emacspeak-ange-ftp-last-percent nil
@@ -621,21 +652,25 @@ before the message is spoken."
 ;;{{{ advising signal
 
 (defadvice signal (before emacspeak pre act compile)
-  "Speak the error message as well."
+  "Speak the error message as well.
+Handle end-of-buffer and beginning-of-buffer specially."
   (declare (special emacspeak-speak-cue-errors))
-  (when emacspeak-speak-cue-errors
+  (let ((error-symbol  (ad-get-arg 0)))
+    (when (or emacspeak-speak-cue-errors
+              (eq error-symbol 'beginning-of-buffer)
+              (eq error-symbol 'end-of-buffer)))
     (let ((dtk-stop-immediately t)
           (message (and (not (eq 'error (ad-get-arg 0)))
                         (get (ad-get-arg 0) 'error-message))))
-      (when  message
-        (dtk-speak message)))))
+      (when  message (dtk-speak message)))))
 
 ;;}}}
 ;;;###autoload
-(defcustom emacspeak-speak-cue-errors t
+(defcustom emacspeak-speak-cue-errors nil
   "Specifies if error messages are cued."
   :type 'boolean
   :group 'emacspeak-spek)
+
 (defadvice error (before emacspeak pre act)
   "Speak the error message.
 Also produces an auditory icon if possible."
@@ -669,6 +704,17 @@ Produce an auditory icon if possible."
       (dtk-say "n" )))
   ad-return-value )
 
+;;}}}
+;;{{{ Advice completion-at-point:
+(defadvice completion-at-point (around emacspeak pre act)
+  "Say what you completed."
+  (let ((orig (point)))
+    ad-do-it
+    (when  (interactive-p)
+      (emacspeak-speak-region orig (point))
+      (emacspeak-auditory-icon 'complete))
+    ad-return-value))
+
 ;;}}}
 ;;{{{  advice various input functions to speak:
 
@@ -682,11 +728,18 @@ Produce an auditory icon if possible."
                                         ;(tts-with-punctuations 'all
                                         ;(dtk-speak (format "%s" ad-return-value)))
     ad-return-value))
-(defadvice read-passwd (before emacspeak pre act comp)
-  "Speak the prompt."
-  (emacspeak-auditory-icon 'open-object)
-  (dtk-stop)
-  (dtk-speak (ad-get-arg 0)))
+(defadvice read-passwd (around emacspeak pre act comp)
+  "Speak the prompt.
+Do not echo the passwd chars as they are typed."
+  (cond
+   ((not (interactive-p)) ad-do-it)
+   (t
+    (let ((echo-keystrokes 0))
+      (emacspeak-auditory-icon 'open-object)
+      (dtk-stop)
+      (dtk-speak (ad-get-arg 0))
+      ad-do-it)))
+  ad-return-value)
 
 (defadvice read-char (before emacspeak pre act comp)
   "Speak the prompt"
@@ -696,6 +749,20 @@ Produce an auditory icon if possible."
      (dtk-speak
       (ad-get-arg 0)))))
 
+(defadvice read-char-choice (before emacspeak pre act comp)
+  "Speak the prompt"
+  (let ((prommmmpt (ad-get-arg 0))
+        (chars (ad-get-arg 1)))
+    (tts-with-punctuations
+     'all
+     (dtk-speak
+      (format "%s: %s"
+              prompt
+              (mapconcat
+               #'(lambda (c) (format "%c" c))
+               chars
+               ", "))))))
+
 (defadvice read-char-exclusive (before emacspeak pre act comp)
   "Speak the prompt"
   (when (ad-get-arg 0)
@@ -705,13 +772,16 @@ Produce an auditory icon if possible."
 
 ;;}}}
 ;;{{{  advice completion functions to speak:
-
-(defadvice dabbrev-expand (after emacspeak pre act)
-  "Say what you completed."
-  (when (interactive-p)
-    (tts-with-punctuations 'all
-                           (dtk-speak
-                            dabbrev--last-expansion))))
+(loop for f in
+      '(dabbrev-expand dabbrev-completion)
+      do
+      (eval
+       `(defadvice,f (after emacspeak pre act)
+          "Say what you completed."
+          (when (interactive-p)
+            (tts-with-punctuations 'all
+                                   (dtk-speak
+                                    dabbrev--last-expansion))))))
 
 (loop for f in
       '(minibuffer-complete-word  minibuffer-complete)
@@ -770,6 +840,19 @@ Produce an auditory icon if possible."
                (or emacspeak-last-message "")))
       ad-return-value)))
 
+(defadvice minibuffer-complete-shell-command (around emacspeak pre act)
+  "Say what you completed."
+  (let ((emacspeak-speak-messages nil)
+        (emacspeak-last-message nil))
+    ad-do-it
+    (when  (interactive-p)
+      (dtk-speak
+       (format "%s %s"
+               (save-excursion (backward-char 1)
+                               (sexp-at-point ))
+               (or emacspeak-last-message "")))
+      ad-return-value)))
+
 (defadvice  next-completion (after emacspeak  pre act comp)
   "Provide auditory feedback."
   (when (interactive-p)
@@ -907,6 +990,11 @@ Produce an auditory icon if possible."
  '(
    (comint-highlight-prompt voice-monotone-medium)
    (comint-highlight-input voice-bolden-medium)))
+(emacspeak-pronounce-add-dictionary-entry
+ 'comint-mode
+ emacspeak-pronounce-sha-checksum-pattern
+ (cons 're-search-forward
+       'emacspeak-pronounce-sha-checksum))
 
 (add-hook 'shell-mode-hook 'emacspeak-pronounce-refresh-pronunciations)
 
@@ -961,8 +1049,7 @@ Produce an auditory icon if possible."
                                                    pre act com)
   "Speak the line showing where point is."
   (when (interactive-p)
-    (let ((emacspeak-show-point t)
-          (voice-lock-mode t))
+    (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
 
@@ -971,8 +1058,7 @@ Produce an auditory icon if possible."
                                                        pre act com)
   "Speak the line showing where point is."
   (when (interactive-p)
-    (let ((emacspeak-show-point t)
-          (voice-lock-mode t))
+    (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
 
@@ -980,8 +1066,7 @@ Produce an auditory icon if possible."
                                         comp)
   "Speak the line showing where point is."
   (when (interactive-p)
-    (let ((emacspeak-show-point t)
-          (voice-lock-mode t))
+    (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
 
@@ -989,8 +1074,7 @@ Produce an auditory icon if possible."
                                          comp)
   "Speak the line showing where point is."
   (when (interactive-p)
-    (let ((emacspeak-show-point t)
-          (voice-lock-mode t))
+    (let ((emacspeak-show-point t))
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
 
@@ -999,7 +1083,7 @@ Produce an auditory icon if possible."
   "Speak the line showing where point is."
   (when (interactive-p)
     (let ((emacspeak-show-point t)
-          (voice-lock-mode t))
+          )
       (emacspeak-auditory-icon 'large-movement)
       (emacspeak-speak-region (point) (mark)))))
 
@@ -1008,7 +1092,7 @@ Produce an auditory icon if possible."
   "Speak the line showing where point is."
   (when (interactive-p)
     (let ((emacspeak-show-point t)
-          (voice-lock-mode t))
+          )
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
 
@@ -1017,7 +1101,7 @@ Produce an auditory icon if possible."
   "Speak the line showing where point is."
   (when (interactive-p)
     (let ((emacspeak-show-point t)
-          (voice-lock-mode t))
+          )
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
 
@@ -1032,7 +1116,7 @@ Produce an auditory icon if possible."
   "Make comint speak its output."
   (let ((inhibit-read-only t)
         (monitor emacspeak-comint-output-monitor)
-		(buffer (process-buffer (ad-get-arg 0)))
+        (buffer (process-buffer (ad-get-arg 0)))
         (dtk-stop-immediately nil))
     (set-buffer buffer)
     ad-do-it
@@ -1073,8 +1157,10 @@ Produce an auditory icon if possible."
           (emacspeak-speak-messages nil))
       ad-do-it
       (if (> (point) prior)
-          (tts-with-punctuations 'all
-                                 (dtk-speak (buffer-substring prior (point ))))
+          (tts-with-punctuations
+           'all
+           (emacspeak-auditory-icon 'complete)
+           (dtk-speak (buffer-substring prior (point ))))
         (emacspeak-speak-completions-if-available))))
    (t ad-do-it))
   ad-return-value)
@@ -1321,6 +1407,48 @@ Produce an auditory icon if possible."
     (message "Checked   in  version %s "
              (emacspeak-vc-get-version-id))))
 
+(loop for f in
+      '(vc-dir-next-line vc-dir-previous-line
+                         vc-dir-next-directory vc-dir-previous-directory
+                         )
+      do
+      (eval
+       `(defadvice ,f (after emacspeak-pre act comp)
+          "Provide auditory feedback."
+          (when (interactive-p)
+            (emacspeak-speak-line)
+            (emacspeak-auditory-icon 'select-object)))))
+
+(defadvice vc-dir-mark-file (after emacspeak-pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'mark-object)))
+
+(defadvice vc-dir-mark (after emacspeak-pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-speak-line)
+    (emacspeak-auditory-icon 'mark-object)))
+
+(defadvice vc-dir (after emacspeak pre act comp)
+  "Produce auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'open-object)
+    (emacspeak-speak-line)))
+
+(defadvice vc-dir-hide-up-to-date (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'task-done)
+    (emacspeak-speak-line)))
+
+(defadvice vc-dir-kill-line (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-speak-line)))
+
 ;;}}}
 ;;{{{  composing mail
 
@@ -1452,10 +1580,9 @@ Produce an auditory icon if possible."
 Use an auditory icon if possible."
   (cond
    ((interactive-p)
-    (let ((count (count-lines (region-beginning)
-                              (region-end))))
-      ad-do-it
+    (let ((count (count-lines (region-beginning) (region-end))))
       (emacspeak-auditory-icon 'delete-object )
+      ad-do-it
       (message "Killed region containing %s lines" count)))
    (t ad-do-it))
   ad-return-value)
@@ -1622,7 +1749,9 @@ Indicate change of selection with
 
 (defadvice describe-function (after emacspeak pre act)
   "Speak the help."
-  (when (interactive-p) (emacspeak-speak-help )))
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'help)
+    (emacspeak-speak-help )))
 
 (defadvice describe-variable (after emacspeak pre act)
   "Speak the help."
@@ -1631,6 +1760,7 @@ Indicate change of selection with
 (defadvice describe-key (after emacspeak pre act)
   "Speak the help."
   (when (interactive-p)
+    (emacspeak-auditory-icon 'help)
     (emacspeak-speak-help )))
 
 (defadvice help-with-tutorial (after emacspeak pre act comp)
@@ -1984,6 +2114,34 @@ Provide an auditory icon if possible."
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line )))
 
+(defvar emacspeak--help-char-helpbuf " *Char Help*"
+  "This is hard-coded in subr.el")
+
+(defadvice help-form-show (after emacspeak pre act comp)
+  "Speak displayed help form."
+  (declare (special emacspeak--help-char-helpbuf))
+  (when (buffer-live-p (get-buffer emacspeak--help-char-helpbuf))
+    (with-current-buffer emacspeak--help-char-helpbuf
+      (goto-char (point-min))
+      (emacspeak-speak-buffer))))
+
+(defadvice tooltip-show-help(after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (let ((msg (ad-get-arg 0)))
+    (if msg
+        (dtk-speak msg)
+      (emacspeak-auditory-icon 'close-object))))
+
+(loop for f in
+      '(tooltip-show-help-non-mode tooltip-sho)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Speak the tooltip."
+          (let ((help (ad-get-arg 0)))
+            (dtk-speak help)
+            (emacspeak-auditory-icon 'help)))))
+
 ;;}}}
 ;;{{{  Emacs server
 
@@ -2120,20 +2278,16 @@ Also produce an auditory icon if possible."
 
 (defsubst emacspeak-isearch-setup()
   "Setup emacspeak environment for isearch."
-  (declare (special emacspeak-speak-messages
-                    emacspeak-speak-cue-errors))
+  (declare (special emacspeak-speak-messages))
   (emacspeak-auditory-icon 'open-object)
-  (setq emacspeak-speak-messages nil
-        emacspeak-speak-cue-errors nil)
+  (setq emacspeak-speak-messages nil)
   (dtk-speak "I-Search: "))
 
 (defsubst emacspeak-isearch-teardown()
   "Teardown emacspeak environment for isearch."
-  (declare (special emacspeak-speak-messages
-                    emacspeak-speak-cue-errors))
+  (declare (special emacspeak-speak-messages))
   (emacspeak-auditory-icon 'close-object)
-  (setq emacspeak-speak-messages t
-        emacspeak-speak-cue-errors t))
+  (setq emacspeak-speak-messages t))
 
 (add-hook 'isearch-mode-hook 'emacspeak-isearch-setup)
 (add-hook 'isearch-mode-end-hook 'emacspeak-isearch-teardown)
@@ -2409,26 +2563,6 @@ Produce auditory icons if possible."
 (defvar emacspeak-minibuffer-enter-auditory-icon t
   "Produce auditory icon when entering the minibuffer.")
 
-;; (defun emacspeak-minibuffer-setup-hook ()
-;;   "Actions  taken when entering the minibuffer with emacspeak. "
-;;   (declare (special emacspeak-minibuffer-enter-auditory-icon
-;;                  minibuffer-default))
-;;   (let ((default
-;;           (cond
-;;            ((and minibuffer-default (listp minibuffer-default))
-;;             (format "Default: %s " (first minibuffer-default)))
-;;            (minibuffer-default
-;;             (format "Default: %s" minibuffer-default))
-;;            (t ""))))
-;;     (when emacspeak-minibuffer-enter-auditory-icon
-;;       (emacspeak-auditory-icon 'open-object))
-;;     (tts-with-punctuations
-;;      'all
-;;      (dtk-speak 
-;;       (format "%s %s"
-;;               (buffer-string)
-;;               default)))))
-
 (defun emacspeak-minibuffer-setup-hook ()
   "Actions to take when entering the minibuffer with
 emacspeak running."
@@ -2505,7 +2639,6 @@ emacspeak running."
   (when (interactive-p)
     (dtk-speak ad-return-value))
   ad-return-value)
-  
 
 (defadvice where-is (around emacspeak pre act comp)
   "Provide spoken feedback"
@@ -2807,6 +2940,62 @@ Variable mark-even-if-inactive is set true ."
      (format "Current input method is %s"
              (or current-input-method "none")))))
 
+;;}}}
+;;{{{ silence midnight cleanup:
+(defadvice clean-buffer-list(around emacspeak pre act comp)
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
+
+;;}}}
+;;{{{ Splash Screen:
+
+(loop for f in
+      '(about-emacs display-about-screen)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback."
+          (when (interactive-p)
+            (emacspeak-auditory-icon 'open-object)
+            (emacspeak-speak-buffer)))))
+
+(defadvice exit-splash-screen (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-speak-mode-line)))
+
+;;}}}
+;;{{{ copyright commands:
+
+(loop for f in
+      '(copyright copyright-update)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback."
+          (when (interactive-p)
+            (emacspeak-auditory-icon 'task-done)
+            (emacspeak-speak-line)))))
+
+(defadvice copyright-update-directory (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'task-done)))
+
+;;}}}
+;;{{{ New buffer switching commands:
+
+(loop for f in
+      '(switch-to-prev-buffer switch-to-next-buffer)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback."
+          (when (interactive-p)
+            (emacspeak-speak-mode-line)
+            (emacspeak-auditory-icon 'select-object)))))
+
 ;;}}}
 (provide 'emacspeak-advice)
 ;;{{{ end of file
