@@ -1,5 +1,5 @@
 ;;; emacspeak-alsaplayer.el --- Control alsaplayer from Emacs
-;;; $Id: emacspeak-alsaplayer.el 6440 2010-02-23 03:45:10Z tv.raman.tv $
+;;; $Id: emacspeak-alsaplayer.el 7057 2011-06-20 00:53:47Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Controlling alsaplayer from emacs 
 ;;; Keywords: Emacspeak, alsaplayer
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2009, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -57,23 +57,35 @@
 ;;}}}
 ;;{{{ define a derived mode for alsaplayer interaction
 
-(defvar emacspeak-alsaplayer-process nil
-  "Process handle to alsaplayer." )
-
 ;;;###autoload
 (define-prefix-command 'emacspeak-alsaplayer-prefix-command
   'emacspeak-alsaplayer-mode-map)
 (defun emacspeak-alsaplayer-header-line ()
   "Return information suitable for header line."
-  (substring
-   (shell-command-to-string "alsaplayer --status | grep title:")
-   0 -1))
+  (let ((title (shell-command-to-string "alsaplayer --status |
+grep title:"))
+        (path (shell-command-to-string "alsaplayer --status |
+grep path:")))
+    (cond
+     ((or (null (get-buffer-process (current-buffer)))
+          (not (eq 'run (process-status (get-buffer-process
+                                         (current-buffer))))))
+      "        No Active Session")
+     ((>  (length title) 0)
+      (substring title 6 -1))
+     ((>  (length path) 0)
+      (setq path (substring path 6 -1))
+      (substring  path
+                  (length (file-name-directory path))))
+     (t "New Session"))))
+(declare-function fundamental-mode ())
 
 (define-derived-mode emacspeak-alsaplayer-mode fundamental-mode 
   "Alsaplayer Interaction"
   "Major mode for alsaplayer interaction. \n\n
 \\{emacspeak-alsaplayer-mode-map}"
-  (setq header-line-format '((:eval (emacspeak-alsaplayer-header-line)))))
+  (setq header-line-format '((:eval
+                              (emacspeak-alsaplayer-header-line)))))
 
 ;;}}}
 ;;{{{ launch  emacspeak-alsaplayer
@@ -88,11 +100,6 @@
   :type 'boolean
   :group 'emacspeak-alsaplayer)
 
-(defcustom emacspeak-alsaplayer-height 1
-  "Height of alsaplayer window."
-  :type 'number
-  :group 'emacspeak-alsaplayer)
-
 ;;;###autoload
 (defcustom emacspeak-alsaplayer-program
   "alsaplayer"
@@ -107,13 +114,15 @@
   :group 'emacspeak-alsaplayer)
 (defvar emacspeak-alsaplayer-buffer "*alsaplayer*"
   "Buffer for alsaplayer interaction.")
-(defcustom emacspeak-alsaplayer-device nil
+(defcustom emacspeak-alsaplayer-device "$ALSA_DEFAULT"
   "Device to use for alsaplayer"
   :type '(choice
           (const  :tag "Ignore" nil)
-          (const  :tag "Card 1" "hw:1,0"))
+          (const  :tag "Card 1" "hw:1,0")
+          (const :tag "ALSA_DEFAULT"  "$ALSA_DEFAULT")
+          (string :tag "Custom"))
   :group  'emacspeak-alsaplayer)
-  
+
 ;;;###autoload
 (defun emacspeak-alsaplayer-launch ()
   "Launch Alsaplayer.
@@ -121,27 +130,24 @@ user is placed in a buffer associated with the newly created
 Alsaplayer session."
   (interactive)
   (declare (special emacspeak-alsaplayer-program emacspeak-alsaplayer-buffer
-		    emacspeak-alsaplayer-device
-                    emacspeak-alsaplayer-height))
+                    emacspeak-alsaplayer-device emacspeak-alsaplayer-height))
   (let ((buffer (get-buffer-create emacspeak-alsaplayer-buffer)))
     (save-current-buffer
       (set-buffer buffer)
       (cond
        ((and (get-buffer-process buffer)
              (eq 'run (process-status (get-buffer-process buffer))))
-        (pop-to-buffer buffer 'other-window)
-        (set-window-text-height nil emacspeak-alsaplayer-height))
+        (pop-to-buffer buffer 'other-window))
        (t
         (setq buffer-undo-list t)
         (shell-command
          (format "%s %s -r -i daemon &"
-		 emacspeak-alsaplayer-program
-		 (if emacspeak-alsaplayer-device
-		     (format "--device %s" emacspeak-alsaplayer-device)
-		   ""))
+                 emacspeak-alsaplayer-program
+                 (if emacspeak-alsaplayer-device
+                     (format "--device %s" emacspeak-alsaplayer-device)
+                   ""))
          (current-buffer))
         (pop-to-buffer buffer 'other-window)
-        (set-window-text-height nil emacspeak-alsaplayer-height)
         (emacspeak-alsaplayer-mode)))
       (when (and emacspeak-alsaplayer-auditory-feedback (interactive-p))
         (emacspeak-auditory-icon 'open-object)
@@ -172,7 +178,7 @@ Optional second arg watch-pattern specifies line of output to
              (eq (current-buffer) (get-buffer emacspeak-alsaplayer-buffer)))
     (goto-char (point-min))
     (search-forward watch-pattern  nil t)))
-         
+
 (defun emacspeak-alsaplayer-add-to-queue (resource)
   "Add specified resource to queue."
   (interactive
@@ -246,12 +252,18 @@ Optional second arg watch-pattern specifies line of output to
     (when  emacspeak-alsaplayer-auditory-feedback
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
+(defvar emacspeak-alsaplayer-paused nil
+  "Record if player is paused.")
 
 (defun emacspeak-alsaplayer-pause ()
   "Pause or resume alsaplayer"
   (interactive)
+  (declare (special emacspeak-alsaplayer-paused))
   (emacspeak-alsaplayer-send-command "--pause"
                                      "position:")
+  (when emacspeak-alsaplayer-paused 
+    (emacspeak-alsaplayer-send-command "--speed 1.0"))
+  (setq emacspeak-alsaplayer-paused (not emacspeak-alsaplayer-paused))
   (when (and emacspeak-alsaplayer-auditory-feedback
              (interactive-p))
     (emacspeak-speak-line)
@@ -276,7 +288,7 @@ Optional second arg watch-pattern specifies line of output to
              (interactive-p))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
-    
+
 (defun emacspeak-alsaplayer-start ()
   "Start  alsaplayer"
   (interactive)
@@ -366,13 +378,13 @@ Optional second arg watch-pattern specifies line of output to
   "Quit  alsaplayer"
   (interactive)
   (let ((kill-buffer-query-functions nil))
-  (emacspeak-alsaplayer-send-command "--quit")
-  (delete-window)
-  (when (and emacspeak-alsaplayer-auditory-feedback (interactive-p))
-    (when (eq major-mode 'emacspeak-alsaplayer-mode)
-      (kill-buffer (current-buffer)))
-    (emacspeak-auditory-icon 'close-object)
-    (emacspeak-speak-mode-line))))
+    (emacspeak-alsaplayer-send-command "--quit")
+    (delete-window)
+    (when (and emacspeak-alsaplayer-auditory-feedback (interactive-p))
+      (when (eq major-mode 'emacspeak-alsaplayer-mode)
+        (kill-buffer (current-buffer)))
+      (emacspeak-auditory-icon 'close-object)
+      (emacspeak-speak-mode-line))))
 
 ;;;###autoload
 (defun emacspeak-alsaplayer-cd (directory)
@@ -490,7 +502,7 @@ Optional second arg watch-pattern specifies line of output to
 (defun emacspeak-alsaplayer-mark-position   ()
   "Mark currently displayed position."
   (interactive)
-  (declare (special emacspeak-alsaplayer-mark))e
+  (declare (special emacspeak-alsaplayer-mark))
   (emacspeak-alsaplayer-status)
   (setq emacspeak-alsaplayer-mark
         (emacspeak-alsaplayer-get-position))
@@ -512,11 +524,8 @@ Optional second arg watch-pattern specifies line of output to
 (defun emacspeak-alsaplayer-info ()
   "Speak current path and copy it to kill ring."
   (interactive)
-  (let ((path (emacspeak-alsaplayer-get-path)))
-    (when path
-      (kill-new path)
-      (emacspeak-auditory-icon 'yank-object)
-      (message "%s" path))))
+  (with-current-buffer emacspeak-alsaplayer-buffer
+    (dtk-speak (emacspeak-alsaplayer-header-line))))
 
 (defvar emacspeak-alsaplayer-mp3split-program "mp3splt"
   "Program used to clip mp3 files.")
@@ -572,7 +581,6 @@ As the default, use current position."
     (setq length (emacspeak-alsaplayer-get-playlist-length))
     (emacspeak-alsaplayer-jump  length)
     (emacspeak-alsaplayer-seek (emacspeak-amark-position amark))))
-  
 
 ;;}}}
 ;;{{{ bind keys
@@ -612,7 +620,7 @@ As the default, use current position."
          emacspeak-alsaplayer-next)
         ("p"
          emacspeak-alsaplayer-previous)
-	("q" bury-buffer)
+        ("q" bury-buffer)
         ("Q" emacspeak-alsaplayer-quit)
         ("o" other-window)
         ("r" emacspeak-alsaplayer-relative)
@@ -629,6 +637,20 @@ As the default, use current position."
       do
       (emacspeak-keymap-update  emacspeak-alsaplayer-mode-map k))
 
+;;}}}
+;;{{{ pause/resume if needed
+
+;;;###autoload
+(defun emacspeak-alsaplayer-pause-or-resume ()
+  "Pause/resume if alsaplayer is running. For use  in
+emacspeak-silence-hook."
+  (declare (special emacspeak-alsaplayer-buffer))
+  (when (and (get-buffer-process emacspeak-alsaplayer-buffer)
+             (eq 'run (process-status (get-buffer-process emacspeak-alsaplayer-buffer))))
+    (emacspeak-alsaplayer-pause)))
+
+(add-hook 'emacspeak-silence-hook 'emacspeak-alsaplayer-pause-or-resume)
+
 ;;}}}
 (provide 'emacspeak-alsaplayer)
 ;;{{{ end of file 
@@ -639,4 +661,4 @@ As the default, use current position."
 ;;; end: 
 
 ;;}}}
- 
+
