@@ -1,5 +1,5 @@
 ;;; emacspeak-calendar.el --- Speech enable Emacs Calendar -- maintain a diary and appointments
-;;; $Id: emacspeak-calendar.el 6610 2010-10-04 23:50:20Z tv.raman.tv $
+;;; $Id: emacspeak-calendar.el 7427 2011-11-22 16:07:26Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extensions to speech enable the calendar.
 ;;; Keywords: Emacspeak, Calendar, Spoken Output
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -131,8 +131,7 @@
 (defadvice view-diary-entries (after emacspeak pre act)
   "Speak the diary entries."
   (when (interactive-p)
-    (let ((voice-lock-mode t)
-          (emacspeak-speak-messages nil))
+    (let ((emacspeak-speak-messages nil))
       (cond
        ((buffer-live-p (get-buffer "*Fancy Diary Entries*"))
         (save-excursion
@@ -144,7 +143,7 @@
 (defadvice  mark-visible-calendar-date (after emacspeak pre act )
   "Use voice locking to mark date. "
   (let ((date (ad-get-arg 0 )))
-    (if (calendar-date-is-legal-p date)
+    (if (calendar-date-is-valid-p date)
         (save-excursion
           (set-buffer calendar-buffer)
           (calendar-cursor-to-visible-date date)
@@ -374,6 +373,7 @@
     (set-buffer calendar-buffer)
     (local-unset-key emacspeak-prefix)
     (define-key calendar-mode-map "v" 'view-diary-entries)
+    (define-key calendar-mode-map "\M-s" 'emacspeak-wizards-sunrise-sunset)
     (define-key calendar-mode-map  "\C-e." 'emacspeak-calendar-speak-date)
     (define-key calendar-mode-map  "\C-ee"
       'calendar-end-of-week)
@@ -382,7 +382,7 @@
             (function (lambda ()
                         ))))
 
-;(add-hook 'calendar-initial-window-hook 'emacspeak-calendar-setup t)
+                                        ;(add-hook 'calendar-initial-window-hook 'emacspeak-calendar-setup t)
 
 ;;}}}
 ;;{{{  Appointments:
@@ -461,7 +461,6 @@ To use, configure variable gweb-my-address via M-x customize-variable."
     (message "Setup for %s"
              gweb-my-address))))
 
-
 (defadvice calendar-sunrise-sunset (around emacspeak pre act comp)
   "Like calendar's sunrise-sunset, but speaks location intelligently."
   (declare (special gweb-my-address))
@@ -476,7 +475,31 @@ To use, configure variable gweb-my-address via M-x customize-variable."
    (t ad-do-it)))
 
 ;;}}}
+;;{{{ Lunar Phases
 
+(loop for f in
+      '(calendar-lunar-phases lunar-phases phases-of-moon)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback."
+          (when (interactive-p)
+            (with-current-buffer lunar-phases-buffer
+              (emacspeak-auditory-icon 'open-object)
+              (emacspeak-speak-buffer))))))
+
+(loop for f in
+      '(holidays calendar-list-holidays)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+          "Provide auditory feedback."
+          (when (interactive-p)
+            (with-current-buffer holiday-buffer
+              (emacspeak-auditory-icon 'open-object)
+              (emacspeak-speak-buffer))))))
+
+;;}}}
 (provide 'emacspeak-calendar)
 ;;{{{ emacs local variables
 
