@@ -1,5 +1,5 @@
 ;;; emacspeak-eterm.el --- Speech enable eterm -- Emacs' terminal emulator  term.el
-;;; $Id: emacspeak-eterm.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;; $Id: emacspeak-eterm.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable eterm. 
 ;;; Keywords: Emacspeak, Eterm, Terminal emulation, Spoken Output
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -656,7 +656,6 @@ sent to the terminal as if it were typed by the user."
     (aset win 3 left-stretch )
     win))
 
-  
 (defsubst emacspeak-eterm-window-top-left (w) (aref w 0 ))
 (defsubst emacspeak-eterm-window-bottom-right (w) (aref w 1 ))
 (defsubst emacspeak-eterm-window-right-stretch (w) (aref w 2 ))
@@ -684,7 +683,7 @@ Argument ID specifies the window."
             (> row bottom-right-row )
             (and (not left-stretch ) (< column top-left-column ))
             (and (not right-stretch ) (> column bottom-right-column )))))))
- 
+
 ;;; Translate a screen position to a buffer position
 
 (defun emacspeak-eterm-coordinates-to-position (coordinates)
@@ -1030,7 +1029,6 @@ available with the prefix emacspeak-eterm-prefix and are listed below:
   (emacspeak-eterm-setup-raw-keys)
   (make-local-variable 'eterm-current-personality)
   (setq eterm-current-personality emacspeak-eterm-default-personality)
-  (voice-lock-mode 1)
   (modify-syntax-entry 10 ">")
   (make-local-variable 'emacspeak-eterm-pointer)
   (setq emacspeak-eterm-pointer  (copy-marker (point)))
@@ -1056,9 +1054,9 @@ Each term-mode buffer has a buffer local value of this variable. ")
   "Tells if eterm output is automatically spoken when in line mode.
 Use command emacspeak-toggle-eterm-autospeak bound to
 \\[emacspeak-toggle-eterm-autospeak] to set this.")
-  
+
 (make-variable-buffer-local 'emacspeak-eterm-autospeak)
-  
+
 (ems-generate-switcher 'emacspeak-toggle-eterm-autospeak
                        'emacspeak-eterm-autospeak
                        "Toggle state of eterm autospeak.
@@ -1079,6 +1077,12 @@ Do not set this by hand.
 Use command emacspeak-eterm-toggle-pointer-mode bound to
 \\[emacspeak-eterm-toggle-pointer-mode].")
 
+(defsubst emacspeak-eterm-activity-in-window (window)
+  "T if terminal activity within bounds of window."
+  (emacspeak-eterm-coordinate-within-window-p
+   (cons (term-current-column) (term-current-row))
+   window))
+
 (defadvice  term-emulate-terminal (around emacspeak pre act compile )
   "Record position, emulate, then speak what happened.
 Also keep track of terminal highlighting etc.  Feedback is
@@ -1098,7 +1102,8 @@ emacspeak-toggle-eterm-autospeak bound to
                     emacspeak-eterm-filter-window emacspeak-eterm-pointer-mode
                     emacspeak-eterm-autospeak 
                     term-current-row term-current-column))
-  (let ((emacspeak-eterm-row (term-current-row ))
+  (let ((emacspeak-eterm-window (get-buffer-window (process-buffer (ad-get-arg 0))))
+        (emacspeak-eterm-row (term-current-row ))
         (emacspeak-eterm-column (term-current-column ))
         (end (point-max))
         (current-char (preceding-char ))
@@ -1111,22 +1116,12 @@ emacspeak-toggle-eterm-autospeak bound to
     (setq new-row (term-current-row )
           new-column (term-current-column )
           new-end (point-max))
-    (when (and  emacspeak-eterm-autospeak
-                (window-live-p
-                 (get-buffer-window (process-buffer (ad-get-arg 0))))
-                (or  (not emacspeak-eterm-focus-window )
-                     (and (emacspeak-eterm-coordinate-within-window-p
-                           (cons new-column new-row )
-                           emacspeak-eterm-focus-window )
-                          (emacspeak-eterm-coordinate-within-window-p
-                           (cons (term-current-column) (term-current-row))
-                           emacspeak-eterm-focus-window ))
-                     (and (emacspeak-eterm-coordinate-within-window-p
-                           (cons new-column new-row )
-                           emacspeak-eterm-filter-window )
-                          (emacspeak-eterm-coordinate-within-window-p
-                           (cons (term-current-column) (term-current-row))
-                           emacspeak-eterm-filter-window ))))
+    (when                        ; do something if in active area
+        (and  emacspeak-eterm-autospeak
+              (window-live-p emacspeak-eterm-window)
+              (or  (not emacspeak-eterm-focus-window )
+                   (emacspeak-eterm-activity-in-window  emacspeak-eterm-focus-window)
+                   (emacspeak-eterm-activity-in-window  emacspeak-eterm-filter-window)))
       (cond
        ((and eterm-char-mode
              emacspeak-eterm-filter-window
@@ -1171,8 +1166,7 @@ emacspeak-toggle-eterm-autospeak bound to
                             (emacspeak-speak-word))        
           (emacspeak-speak-word )))
        (t (emacspeak-speak-line nil )))
-      (when (and (not  emacspeak-eterm-pointer-mode )
-                 emacspeak-eterm-pointer)
+      (when (and (not  emacspeak-eterm-pointer-mode ) emacspeak-eterm-pointer)
         (emacspeak-eterm-pointer-to-cursor)))))
 
 (ems-generate-switcher 'emacspeak-eterm-toggle-pointer-mode
@@ -1183,7 +1177,6 @@ When emacspeak eterm is in pointer mode, the eterm read pointer
 stays where it is rather than automatically moving to the terminal cursor when
 there is terminal activity.")
 
-   
 (defadvice term-dynamic-complete (around emacspeak pre act)
   "Speak the completion. "
   (declare (special emacspeak-eterm-row term-current-row))
@@ -1363,7 +1356,7 @@ emacspeak-eterm-remote-hostnames")
   (unless (intern-soft host emacspeak-eterm-remote-hosts-table)
     (emacspeak-eterm-cache-remote-host host))
   (switch-to-buffer (format "*%s-terminal*" host) ))
-     
+
 ;;}}}
 (provide 'emacspeak-eterm)
 ;;{{{  emacs local variables
