@@ -1,5 +1,5 @@
 ;;; emacspeak-forms.el --- Speech enable Emacs' forms mode  -- provides  a convenient database interface
-;;; $Id: emacspeak-forms.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;; $Id: emacspeak-forms.el 7323 2011-10-26 00:50:39Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for forms-mode 
 ;;; Keywords:emacspeak, audio interface to emacs forms 
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1996 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -93,8 +93,7 @@ speak the first field")
   "Speak current form field name and value.
 Assumes that point is at the front of a field value."
   (interactive)
-  (let ((voice-lock-mode t)
-        (name nil)
+  (let ((name nil)
         (value nil)
         (n-start nil))
     (save-excursion
@@ -274,7 +273,6 @@ Assumes that point is at the front of a field value."
                     forms-mode-map))
 ;;; move to first field
              (forms-next-field 1))))
-  
 
 ;;}}}
 (provide  'emacspeak-forms)
