@@ -1,5 +1,5 @@
 ;;; emacspeak-man.el --- Speech enable Man mode -- Use this for UNIX Man pages
-;;; $Id: emacspeak-man.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;; $Id: emacspeak-man.el 7520 2012-02-27 01:07:12Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for man-mode
 ;;; Keywords:emacspeak, audio interface to emacs man 
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -73,7 +73,6 @@ Also provide an auditory icon"
   (setq imenu-generic-expression
         '((nil "\n\\([A-Z].*\\)" 1)     ; SECTION, but not TITLE
           ("*Subsections*" "^   \\([A-Z].*\\)" 1)))
-  (voice-lock-mode 1)
   (dtk-set-punctuations 'all)
   (emacspeak-pronounce-refresh-pronunciations)
   (emacspeak-auditory-icon 'help))
@@ -158,9 +157,7 @@ Also provide an auditory icon"
   (emacspeak-execute-repeatedly 'forward-paragraph))
 (autoload 'emacspeak-view-line-to-top 
   "emacspeak-view" "Move current line to top of window"  t)
-(declaim (special Man-mode-map))
-(eval-when (load)
-  )
+
 (declaim (special  Man-mode-map))
 (define-key Man-mode-map ";"
   'emacspeak-speak-current-window)
@@ -169,6 +166,8 @@ Also provide an auditory icon"
 (define-key Man-mode-map "." 'emacspeak-man-browse-man-page)
 (define-key Man-mode-map "t" 'emacspeak-view-line-to-top)
 (define-key Man-mode-map "'" 'emacspeak-speak-rest-of-buffer)
+(define-key Man-mode-map "N" 'emacspeak-speak-next-personality-chunk)
+(define-key Man-mode-map "P" 'emacspeak-speak-previous-personality-chunk)
 (define-key Man-mode-map "[" 'backward-paragraph)
 (define-key Man-mode-map "]" 'forward-paragraph)
 
