@@ -1,5 +1,5 @@
 ;;; emacspeak-org.el --- Speech-enable org
-;;; $Id: emacspeak-org.el 6569 2010-08-26 22:53:31Z tv.raman.tv $
+;;; $Id: emacspeak-org.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for ORG
 ;;; Keywords: Emacspeak, org
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -87,12 +87,14 @@
 
 (loop for f in
       '(org-mark-ring-goto
-        org-next-link org-previous-link
+        org-forward-same-level org-backward-same-level
+        org-next-link org-previous-link org-open-at-point
         org-goto  org-goto-ret
         org-goto-left org-goto-right
         org-goto-quit
         org-next-item org-previous-item
         org-metaleft org-metaright org-metaup org-metadown
+        org-meta-return
         org-shiftmetaleft org-shiftmetaright org-shiftmetaup org-shiftmetadown
         )
       do
@@ -102,6 +104,7 @@
           (when (interactive-p)
             (emacspeak-speak-line)
             (emacspeak-auditory-icon 'large-movement)))))
+
 (defadvice org-cycle-list-bullet (after emacspeak pre act comp)
   "Provide spoken feedback."
   (when (interactive-p)
@@ -150,12 +153,12 @@
 (loop for f in
       '(
         org-insert-heading org-insert-todo-heading
-        org-insert-subheading org-insert-todo-subheading
-        org-promote-subtree org-demote-subtree
-        org-do-promote org-do-demote
-        org-move-subtree-up org-move-subtree-down
-        org-convert-to-odd-levels org-convert-to-oddeven-levels
-        )
+                           org-insert-subheading org-insert-todo-subheading
+                           org-promote-subtree org-demote-subtree
+                           org-do-promote org-do-demote
+                           org-move-subtree-up org-move-subtree-down
+                           org-convert-to-odd-levels org-convert-to-oddeven-levels
+                           )
       do
       (eval
        `(defadvice ,f(after emacspeak pre act comp)
@@ -170,8 +173,8 @@
 (loop for f in
       '(
         org-cut-subtree org-copy-subtree
-        org-paste-subtree org-archive-subtree
-        org-narrow-to-subtree )
+                        org-paste-subtree org-archive-subtree
+                        org-narrow-to-subtree )
       do
       (eval
        `(defadvice ,f(after emacspeak pre act comp)
@@ -222,7 +225,7 @@
 (loop for f in
       '(
         org-timestamp-down org-timestamp-down-day
-        org-timestamp-up org-timestamp-up-day)
+                           org-timestamp-up org-timestamp-up-day)
       do
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
@@ -243,9 +246,9 @@
 (loop for f in
       '(
         org-agenda-next-date-line org-agenda-previous-date-line
-        org-agenda-next-line org-agenda-previous-line
-        org-agenda-goto-today
-        )
+                                  org-agenda-next-line org-agenda-previous-line
+                                  org-agenda-goto-today
+                                  )
       do
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
@@ -253,7 +256,7 @@
           (when (interactive-p)
             (emacspeak-auditory-icon 'select-object)
             (emacspeak-speak-line)))))
-            
+
 (loop for f in
       '(
         org-agenda-quit org-agenda-exit)
@@ -280,7 +283,7 @@
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
-                                  
+
 ;;}}}
 ;;{{{ tables:
 
@@ -316,6 +319,12 @@
   (declare (special org-goto-map org-mode-map))
   (loop for k in
         '(
+          ([(meta return)] org-meta-return)
+          ([(meta up)] org-metaup)
+          ([(meta down)] org-metadown)
+          ([(meta left)] org-metaleft)
+          ([(shift right)] org-shiftright)
+          ([(meta right)] org-metaright)
           ([(shift tab)]    org-shifttab)
           ([(shift up)] org-shiftup)
           ([(shift down)] org-shiftdown)
@@ -327,6 +336,7 @@
           ([(meta shift left)] org-shiftmetaleft)
           ([(meta shift right)] org-shiftmetaright)
           ([(meta shift return)] org-insert-todo-heading)
+          ("\C-e" emacspeak-prefix-command)
           ("\C-j" org-insert-heading)
           ("\M-n" org-next-item)
           ("\M-p" org-previous-item)
@@ -358,7 +368,7 @@
   "speak char that was inserted."
   (when (and emacspeak-character-echo
              (interactive-p ))
-    (when dtk-stop-immediately-while-typing (dtk-stop))
+    (dtk-stop)
     (emacspeak-speak-this-char last-input-event )))
 
 (defadvice org-delete-char (around emacspeak pre act)
@@ -413,18 +423,16 @@
 (loop for f in
       '(
         org-occur org-next-link org-previous-link
-        org-beginning-of-item
-        org-beginning-of-item-list
-        org-back-to-heading
-        org-insert-heading org-insert-todo-heading)
+                  org-beginning-of-item
+                  org-beginning-of-item-list
+                  org-back-to-heading
+                  org-insert-heading org-insert-todo-heading)
       do
       (eval
        `(defadvice ,f (around emacspeak pre act comp)
           "Avoid outline errors bubbling up."
           
           (ems-with-errors-silenced ad-do-it))))
-           
-          
 
 ;;}}}
 ;;{{{ global input wizard
@@ -435,6 +443,40 @@
   (interactive)
   (emacspeak-wizards-popup-input-buffer 'org-mode))
 
+;;}}}
+;;{{{ org capture
+
+(defcustom emacspeak-org-bookmark-key "h"
+  "Key of template used for capturing  hot list."
+  :type 'string
+  :group 'emacspeak-org)
+
+;;;###autoload
+(defun emacspeak-org-bookmark (&optional goto)
+  "Bookmark from org."
+  (interactive "P")
+  (declare (special emacspeak-org-bookmark-key))
+  (org-capture goto emacspeak-org-bookmark-key))
+
+(defadvice org-capture-goto-last-stored (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
+    (emacspeak-speak-line)))
+
+(defadvice org-capture-goto-target (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (emacspeak-auditory-icon 'large-movement)
+  (emacspeak-speak-line))
+
+(defadvice org-capture-finalize (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (emacspeak-auditory-icon 'save-object))
+
+(defadvice org-capture-kill (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (emacspeak-auditory-icon 'close-object))
+
 ;;}}}
 (provide 'emacspeak-org)
 ;;{{{ end of file
