@@ -1,5 +1,5 @@
 ;;; emacspeak-personality.el ---Emacspeak's new personality interface
-;;; $Id: emacspeak-personality.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;; $Id: emacspeak-personality.el 7578 2012-03-17 02:52:37Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Voice lock implementation
 ;;; Keywords: Emacspeak,  Spoken Output, audio formatting
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -83,27 +83,17 @@
 (require 'advice)
 (require 'voice-setup)
 
-;;}}}
-;;{{{ attach voice lock to global font lock
-(defadvice font-lock-mode (after  emacspeak pre act comp)
-  "Attach voice-lock-mode to font-lock-mode."
-  (voice-lock-mode   font-lock-mode))
-(defadvice global-font-lock-mode (after emacspeak pre act comp)
-  "Attach voice lock to font lock."
-  (when global-font-lock-mode
-    (setq-default voice-lock-mode t)))
-
 ;;}}}
 ;;{{{ cumulative personalities
 
 ;;;###autoload
 (defsubst emacspeak-personality-put (start end personality object)
-  "Apply personality to specified region, over-writing any current
-personality settings."
+  "Apply personality to specified region, over-writing any current personality settings."
   (when (and (integer-or-marker-p start)
              (integer-or-marker-p end )
              (not (= start end)))
-    (let ((v (if (listp personality)
+    (let ((inhibit-read-only t)
+          (v (if (listp personality)
                  (delete-duplicates personality :test #'eq)
                personality)))
       (ems-modify-buffer-safely
@@ -113,108 +103,114 @@ personality settings."
 (defun emacspeak-personality-append  (start end personality &optional object )
   "Append specified personality to text bounded by start and end.
 Existing personality properties on the text range are preserved."
-  (when (and (integer-or-marker-p start)
-             (integer-or-marker-p end )
-             (not (= start end)))
-    (ems-modify-buffer-safely
-     (let ((v (if (listp personality)
-                  (delete-duplicates personality :test #'eq)
-                personality))
-           (orig (get-text-property start 'personality object))
-           (new nil)
-           (extent
-            (next-single-property-change
-             start 'personality object end)))
-       (cond
-        ((null orig)                    ;simple case
-         (ad-Orig-put-text-property start extent 'personality v object)
-         (when (< extent end)
-           (emacspeak-personality-append extent end v object)))
-        (t                             ;accumulate the new personality
-         (unless (or (equal  v orig)
-                     (listp orig)
-                     (and (listp orig)(memq v orig)))
-           (setq new
-                 (delete-duplicates
-                  (nconc
-                   (if (listp orig) orig (list orig))
-                   (if (listp v) v (list v)))))
-           (ad-Orig-put-text-property start extent
-                                      'personality new object))
-         (when (< extent end)
-           (emacspeak-personality-append extent end v object))))))))
+  (condition-case nil
+      (when (and (integer-or-marker-p start)
+                 (integer-or-marker-p end )
+                 (not (= start end)))
+        (ems-modify-buffer-safely
+         (let ((inhibit-read-only t)
+               (v (if (listp personality)
+                      (delete-duplicates personality :test #'eq)
+                    personality))
+               (orig (get-text-property start 'personality object))
+               (new nil)
+               (extent
+                (next-single-property-change
+                 start 'personality object end)))
+           (cond
+            ((null orig)                    ;simple case
+             (ad-Orig-put-text-property start extent 'personality v object)
+             (when (< extent end)
+               (emacspeak-personality-append extent end v object)))
+            (t                             ;accumulate the new personality
+             (unless (or (equal  v orig)
+                         (listp orig)
+                         (and (listp orig)(memq v orig)))
+               (setq new
+                     (delete-duplicates
+                      (nconc
+                       (if (listp orig) orig (list orig))
+                       (if (listp v) v (list v)))))
+               (ad-Orig-put-text-property start extent
+                                          'personality new object))
+             (when (< extent end)
+               (emacspeak-personality-append extent end v object)))))))
+    (error nil)))
 
 ;;;###autoload
 (defun emacspeak-personality-prepend  (start end
                                              personality &optional object)
   "Prepend specified personality to text bounded by start and end.
 Existing personality properties on the text range are preserved."
-  (when (and (integer-or-marker-p start)
-             (integer-or-marker-p end )
-             (not (= start end)))
-    (ems-modify-buffer-safely
-     (let ((v (if (listp personality)
-                  (delete-duplicates personality :test #'eq)
-                personality))
-           (orig (get-text-property start 'personality object))
-           (new nil)
-           (extent
-            (next-single-property-change
-             start 'personality object end)))
-       (cond
-        ((null orig)                    ;simple case
-         (ad-Orig-put-text-property start extent 'personality v object)
-         (when (< extent end)
-           (emacspeak-personality-prepend extent end v object)))
-        (t                             ;accumulate the new personality
-         (unless (or (equal v orig)
-                     (listp orig)
-                     (and (listp orig) (memq v orig)))
-           (setq new
-                 (delete-duplicates
-                  (nconc
-                   (if (listp v) v (list v))
-                   (if (listp orig) orig (list orig)))))
-           (ad-Orig-put-text-property start extent
-                                      'personality new object))
-         (when (< extent end)
-           (emacspeak-personality-prepend extent end v object))))))))
-
+  (condition-case nil
+      (when (and (integer-or-marker-p start)
+                 (integer-or-marker-p end )
+                 (not (= start end)))
+        (ems-modify-buffer-safely
+         (let ((v (if (listp personality)
+                      (delete-duplicates personality :test #'eq)
+                    personality))
+               (orig (get-text-property start 'personality object))
+               (new nil)
+               (extent
+                (next-single-property-change
+                 start 'personality object end)))
+           (cond
+            ((null orig)                    ;simple case
+             (ad-Orig-put-text-property start extent 'personality v object)
+             (when (< extent end)
+               (emacspeak-personality-prepend extent end v object)))
+            (t                             ;accumulate the new personality
+             (unless (or (equal v orig)
+                         (listp orig)
+                         (and (listp orig) (memq v orig)))
+               (setq new
+                     (delete-duplicates
+                      (nconc
+                       (if (listp v) v (list v))
+                       (if (listp orig) orig (list orig)))))
+               (ad-Orig-put-text-property start extent
+                                          'personality new object))
+             (when (< extent end)
+               (emacspeak-personality-prepend extent end v object)))))))
+    (error nil)))
 (defun emacspeak-personality-remove  (start end
                                             personality
                                             &optional object)
   "Remove specified personality from text bounded by start and end.
 Other existing personality properties on the text range are
 preserved."
-  (when (and (integer-or-marker-p start)
-             (integer-or-marker-p end )
-             (not (= start end)))
-    (ems-modify-buffer-safely
-     (let ((orig (get-text-property start 'personality object))
-           (new nil)
-           (extent
-            (next-single-property-change
-             start 'personality (current-buffer) end)))
-       (cond
-        ((null orig)                    ;simple case
-         (when (< extent end)
-           (emacspeak-personality-remove extent end personality)))
-        (t                              ;remove the new personality
-         (setq new
-               (cond
-                ((equal orig personality) nil)
-                ((listp orig)
-                 (remove personality orig))
-                (t nil)))
-         (if new
-             (ad-Orig-put-text-property start extent
-                                        'personality new object)
-           (ad-Orig-remove-text-properties start extent
-                                           (list 'personality )
-                                           object))
-         (when (< extent end)
-           (emacspeak-personality-remove extent end
-                                         personality))))))))
+  (condition-case nil
+      (when (and (integer-or-marker-p start)
+                 (integer-or-marker-p end )
+                 (not (= start end)))
+        (ems-modify-buffer-safely
+         (let ((orig (get-text-property start 'personality object))
+               (new nil)
+               (extent
+                (next-single-property-change
+                 start 'personality (current-buffer) end)))
+           (cond
+            ((null orig)                    ;simple case
+             (when (< extent end)
+               (emacspeak-personality-remove extent end personality)))
+            (t                              ;remove the new personality
+             (setq new
+                   (cond
+                    ((equal orig personality) nil)
+                    ((listp orig)
+                     (remove personality orig))
+                    (t nil)))
+             (if new
+                 (ad-Orig-put-text-property start extent
+                                            'personality new object)
+               (ad-Orig-remove-text-properties start extent
+                                               (list 'personality )
+                                               object))
+             (when (< extent end)
+               (emacspeak-personality-remove extent end
+                                             personality)))))))
+    (error nil)))
 
 ;;}}}
 ;;{{{ helper: face-p
