@@ -1,5 +1,5 @@
 ;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries
-;;; $Id: emacspeak-pronounce.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;; $Id: emacspeak-pronounce.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
@@ -127,7 +127,6 @@ Argument KEY specifies a dictionary key e.g. directory, mode etc."
     (remhash    string
                 emacspeak-pronounce-pronunciation-table)))
 
-  
 (defun emacspeak-pronounce-add-buffer-local-dictionary-entry  (string pronunciation)
   "Add specified pronunciation for current buffer.
 Arguments STRING and PRONUNCIATION specify what is being defined."
@@ -215,7 +214,8 @@ modes."
 
 ;;; c++ mode inherits from C mode
 (emacspeak-pronounce-add-super  'c-mode 'c++-mode)
-
+;;; shell inherits from comint:
+(emacspeak-pronounce-add-super 'comint-mode 'shell-mode)
 ;;; latex-mode and latex2e-mode inherit from plain-tex-mode
 
 (emacspeak-pronounce-add-super  'plain-tex-mode 'latex-mode)
@@ -226,6 +226,12 @@ modes."
 (emacspeak-pronounce-add-super 'text-mode 'plain-tex-mode)
 ;;;xsl inherits from xml
 (emacspeak-pronounce-add-super 'xml-mode 'xsl-mode)
+
+;;; VM, w3m, w3
+(emacspeak-pronounce-add-super 'text-mode 'w3m-mode)
+(emacspeak-pronounce-add-super 'text-mode 'w3-mode)
+(emacspeak-pronounce-add-super 'text-mode 'vm-presentation-mode)
+
 ;;}}}
 ;;{{{  Composing and applying dictionaries:
 
@@ -623,7 +629,6 @@ pronunciation dictionary for the specified key."
     (setq buffer (get-buffer-create buffer-name))
     (save-excursion
       (set-buffer  buffer)
-      (voice-lock-mode t)
       (widget-insert "\n")
       (widget-insert
        (format "Editting pronunciation dictionary for %s\n\n" key))
@@ -739,7 +744,7 @@ specified pronunciation dictionary key."
                 (+ 1900 (third fields)))
                (t (third fields)))))
        'personality voice-punctuations-some))))
-                   
+
 ;;}}}
 ;;{{{ phone numbers
 
@@ -767,6 +772,17 @@ specified pronunciation dictionary key."
      (format "%s %s, %s. "
              area-code prefix-code suffix-code)
      'personality voice-punctuations-some)))
+(defvar emacspeak-pronounce-sha-checksum-pattern 
+  "[0-9a-f]\\{40\\}"
+  "Regexp pattern that matches 40-digit SHA  check-sum.")
+
+(defun emacspeak-pronounce-sha-checksum (sha)
+  "Return pronunciation for 40 digit SHA hash. Useful for working with Git among other things."
+  (when
+      (and
+       (= 40 (length sha))
+       (string-match "[0-9a-f]+" sha))
+    (format "sha: %s " (substring sha 0 5))))
 
 ;;}}}
 
