@@ -1,5 +1,5 @@
 ;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI
-;;; $Id: emacspeak-table-ui.el 6476 2010-04-23 01:02:11Z tv.raman.tv $
+;;; $Id: emacspeak-table-ui.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1995 by T. V. Raman
 ;;; All Rights Reserved.
 ;;;
@@ -344,7 +344,7 @@ specifies the filter"
 Optional prefix arg prompts for a new filter."
   (interactive "P")
   (declare (special emacspeak-table-speak-row-filter
-  emacspeak-table))
+                    emacspeak-table))
   (and emacspeak-table-speak-row-filter(push emacspeak-table-speak-row-filter minibuffer-default))
   (unless (and  emacspeak-table-speak-row-filter
                 (listp emacspeak-table-speak-row-filter)
@@ -358,54 +358,53 @@ Optional prefix arg prompts for a new filter."
     (emacspeak-table-ui-filter-set
      (emacspeak-table-ui-generate-key)
      emacspeak-table-speak-row-filter))
-  (let ((voice-lock-mode t))
-    (message
-     (mapconcat
-      #'(lambda (token)
-          (let ((value nil))
-            (cond
-             ((stringp token) token)
-             ((numberp token)
-              (setq value
-                    (emacspeak-table-get-entry-with-headers
-                     (emacspeak-table-current-row emacspeak-table)
-                     token))
-              (put-text-property 0 (length value)
-                                 'face 'bold  value)
-              value)
-             ((and (listp token)
-                   (numberp (first token))
-                   (numberp (second token )))
-              (setq value
-                    (emacspeak-table-get-entry-with-headers
-                     (first token)
-                     (second token)))
-              (put-text-property 0 (length value)
-                                 'face 'bold value)
-              value)
-             ((and
-               (symbolp (first token))
-               (fboundp  (first token)))
-              (setq value
-                    (funcall
-                     (first token)
-                     (cond
-                      ((and (= 2 (length token))
-                            (numberp (second token)))
-                       (emacspeak-table-get-entry-with-headers
-                        (emacspeak-table-current-row emacspeak-table)
-                        (second token)))
-                      ((and (= 3 (length token))
-                            (numberp (second token))
-                            (numberp (third token)))
-                       (emacspeak-table-get-entry-with-headers
-                        (second token) (third token))))))
-              (put-text-property 0 (length value)
-                                 'face 'bold  value)
-              value)
-             (t  (format "%s" token)))))
-      emacspeak-table-speak-row-filter
-      " "))))
+  (message
+   (mapconcat
+    #'(lambda (token)
+        (let ((value nil))
+          (cond
+           ((stringp token) token)
+           ((numberp token)
+            (setq value
+                  (emacspeak-table-get-entry-with-headers
+                   (emacspeak-table-current-row emacspeak-table)
+                   token))
+            (put-text-property 0 (length value)
+                               'face 'bold  value)
+            value)
+           ((and (listp token)
+                 (numberp (first token))
+                 (numberp (second token )))
+            (setq value
+                  (emacspeak-table-get-entry-with-headers
+                   (first token)
+                   (second token)))
+            (put-text-property 0 (length value)
+                               'face 'bold value)
+            value)
+           ((and
+             (symbolp (first token))
+             (fboundp  (first token)))
+            (setq value
+                  (funcall
+                   (first token)
+                   (cond
+                    ((and (= 2 (length token))
+                          (numberp (second token)))
+                     (emacspeak-table-get-entry-with-headers
+                      (emacspeak-table-current-row emacspeak-table)
+                      (second token)))
+                    ((and (= 3 (length token))
+                          (numberp (second token))
+                          (numberp (third token)))
+                     (emacspeak-table-get-entry-with-headers
+                      (second token) (third token))))))
+            (put-text-property 0 (length value)
+                               'face 'bold  value)
+            value)
+           (t  (format "%s" token)))))
+    emacspeak-table-speak-row-filter
+    " ")))
 
 (defvar emacspeak-table-speak-column-filter nil
   "Template specifying how a column is filtered before it is spoken.")
@@ -570,7 +569,7 @@ the documentation on the table browser."
     (when (= (preceding-char) ?,)
       (push "" fields))
     (nreverse fields)))
-        
+
 ;;;###autoload
 (defun emacspeak-table-find-csv-file (filename)
   "Process a csv (comma separated values) file.
@@ -1032,6 +1031,17 @@ table markup.")
                                   (emacspeak-table-markup-get-table
                                    'latex2e-mode))
 
+(emacspeak-table-markup-set-table
+ 'org-mode
+ (emacspeak-table-make-markup
+  :table-start ""
+  :table-end ""
+  :row-start "|"
+  :row-end "|\n"
+  :col-start ""
+  :col-end ""
+  :col-separator "|"))
+
 (emacspeak-table-markup-set-table 'fundamental-mode
                                   (emacspeak-table-make-markup
                                    :table-start ""
@@ -1091,8 +1101,7 @@ markup to use."
         (col-end nil)
         (col-separator nil))
     (cond
-     (read-only
-      (error "Cannot paste into read only buffer."))
+     (read-only (error "Cannot paste into read only buffer."))
      (t (setq markup  (emacspeak-table-markup-get-table mode))
         (setq table-start (emacspeak-table-markup-table-start markup)
               table-end (emacspeak-table-markup-table-end markup)
