@@ -1,5 +1,5 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris
-;;; $Id: emacspeak-tetris.el 6641 2010-11-23 23:52:58Z tv.raman.tv $
+;;; $Id: emacspeak-tetris.el 7280 2011-10-16 16:04:28Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to tetris
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2009, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -41,9 +41,6 @@
 ;;{{{  Required modules
 
 (require 'emacspeak-preamble)
-(condition-case nil
-    (require 'tetris)            ;FC2 Emacs doesn't contain tetris.el?
-  )
 ;;}}}
 ;;{{{  Introduction 
 
@@ -62,20 +59,20 @@
   (require 'emacspeak-pronounce)
   (unless emacspeak-tetris-pronunciations-defined
     (setq emacspeak-tetris-pronunciations-defined t)
-    (emacspeak-pronounce-set-dictionary
-       'tetris-mode
-       '(("." . "")
-         ("" . "")                    ;ascii 8: border
-         (" " . " 1 ")                 ; ascii 0: block
-         ("" . " 2 ")                 ; Ascii 1: right elbow
-         ("" . " 3 ")                 ; ascii 2: left elbow
-         ("" . " 4 ")                 ; ascii 3: Z
-         ("" . " 5 ")                 ; Ascii 4: S
-         ("" . " 6 ")                 ; Ascii 5: inverted T
-         ("" . " 7 ")                 ; ascii 6: Edge
-         ("." . "")
-         ("" . "-")                   ; ascii 7: blank
-         )))
+    (mapcar
+     #'(lambda (entry)
+         (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
+                                                   (car entry) (cdr entry)))
+     '(("" . " 1 ")
+       ("" . " 6 ")
+       ("" . " 7 ")
+       ("" . " 5 ")
+       ("" . " 4 ")
+       ("" . " 3 ")
+       ("" . " 2 ")
+       (" " . "-")
+       ("" . "")                      ;border char
+       ("." . ""))))
   (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
             (not emacspeak-pronounce-pronunciation-table))
     (emacspeak-pronounce-toggle-use-of-dictionaries)))
@@ -199,7 +196,7 @@
 ;;}}}
 ;;{{{  Advice
 
-(defvar emacspeak-tetris-tick-period 1
+(defvar emacspeak-tetris-tick-period 15
   "*Set this to a convenient value so you get time to look at what is
 going on. Reduce it as you get better.")
 
@@ -357,41 +354,45 @@ concentration and the game is a good mental challenge. "
   "Provide spoken feedback"
   (emacspeak-tetris-speak-current-shape))
 
-(loop for f in
-      '(tetris-rotate-prev tetris-rotate-next)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback"
-          (when (interactive-p) (emacspeak-tetris-speak-current-shape)))))
-           
+(defadvice tetris-rotate-next (after emacspeak pre act comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (emacspeak-tetris-speak-current-shape)))
+
+(defadvice tetris-rotate-prev (after emacspeak pre act comp)
+  "Provide auditory feedback"
+  (when (interactive-p)
+    (emacspeak-tetris-speak-current-shape)))
+
 (defadvice tetris-move-left-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-tetris-speak-current-shape-and-coordinates)))
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-tetris-speak-current-shape-and-coordinates)))
+    (emacspeak-tetris-speak-column)))
+
+(defadvice tetris-move-to-x-pos (after emacspeak pre act comp)
+  "Speak coordinates"
+  (when (interactive-p)
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-left (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-current-shape-and-coordinates)))
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right (after emacspeak pre act comp)
   "Speak coordinates"
   (when (interactive-p)
-    (emacspeak-tetris-speak-current-shape-and-coordinates)))
+    (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-bottom (after emacspeak pre act comp)
   "Provide auditory feedback as the tile falls"
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)))
-
 (defvar emacspeak-tetris-filled-a-row nil
   "Temporary flag indicating if we just filled a row.")
 
@@ -475,18 +476,18 @@ concentration and the game is a good mental challenge. "
       (setq hit (tetris-test-shape)))
     (tetris-draw-shape)))
 
-a(defun tetris-move-right-edge ()
-   "Moves the shape to the right edge  of the playing area"
-   (interactive)
-   (declare (special tetris-pos-x tetris-width))
-   (let ((hit nil)
-         (max(- tetris-width (tetris-shape-width))))
-     (tetris-erase-shape)
-     (while(and (< tetris-pos-x max)
-                (not hit))
-       (setq tetris-pos-x (1+ tetris-pos-x))
-       (setq hit (tetris-test-shape)))
-     (tetris-draw-shape)))
+(defun tetris-move-right-edge ()
+  "Moves the shape to the right edge  of the playing area"
+  (interactive)
+  (declare (special tetris-pos-x tetris-width))
+  (let ((hit nil)
+        (max(- tetris-width (tetris-shape-width))))
+    (tetris-erase-shape)
+    (while(and (< tetris-pos-x max)
+               (not hit))
+      (setq tetris-pos-x (1+ tetris-pos-x))
+      (setq hit (tetris-test-shape)))
+    (tetris-draw-shape)))
 
 (defun tetris-move-to-x-pos ()
   "Moves the shape to a specified x position if possible"
@@ -516,8 +517,7 @@ a(defun tetris-move-right-edge ()
         (setq tetris-pos-x (1- tetris-pos-x))
         (setq hit (tetris-test-shape))
         (incf diff))))
-    (tetris-draw-shape)
-    (emacspeak-tetris-speak-current-shape-and-coordinates)))
+    (tetris-draw-shape)))
 
 ;;}}}
 ;;{{{ column browsing
@@ -542,7 +542,7 @@ a(defun tetris-move-right-edge ()
   (dtk-speak (emacspeak-tetris-get-column-contents x)))
 
 ;;}}}
-(provide 'emacspeak-tetris)o
+(provide 'emacspeak-tetris)
 ;;{{{ end of file 
 
 ;;; local variables:
