@@ -1,5 +1,5 @@
 ;;; emacspeak-url-template.el --- Create library of URI templates
-;;; $Id: emacspeak-url-template.el 6620 2010-10-19 21:00:44Z tv.raman.tv $
+;;; $Id: emacspeak-url-template.el 7570 2012-03-11 16:20:35Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:   Implement library of URI templates
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2009, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -268,8 +268,7 @@ dont-url-encode if true then url arguments are not url-encoded "
  nil
  "Display package tracking information from UPS."
  #'(lambda (url)
-     (emacspeak-we-extract-table-by-match "Package Progress"
-                                          url 'speak)))
+     (emacspeak-we-extract-by-class "dataTable" url 'speak)))
 
 ;;}}}
 ;;{{{ amazon
@@ -281,29 +280,7 @@ dont-url-encode if true then url arguments are not url-encoded "
  "Retrieve product details from Amazon by either ISBN or ASIN.")
 ;;}}}
 ;;{{{ bookshare
-(defcustom emacspeak-bookshare-user-id nil
-  "Bookshare user Id."
-  :type '(choice :tag "Bookshare User id"
-                 (const :tag "None" nil)
-                 (string :tag "Email"))
-  :group 'emacspeak-url-template)
-
-(emacspeak-url-template-define
- "BookShare"
- "https://www.bookshare.org/whiteListRedirect?j_userName=%s"
- (list
-  #'(lambda nil
-      (read-from-minibuffer "Bookshare UserId: "
-                            emacspeak-bookshare-user-id)))
- nil
- "Bookshare Login")
-
-(emacspeak-url-template-define
- "BookShare Search"
- "http://www.bookshare.org/quickSearch?keyword=%s&search=Search"
- (list "BookShare Query: ")
- nil
- "BookShare Search")
+;;; replacing with API  client:
 
 (defun emacspeak-url-template-calendar-to-seconds ()
   "Convert date under cursor to seconds since epoch."
@@ -317,15 +294,6 @@ dont-url-encode if true then url arguments are not url-encoded "
                           (first date)
                           (third date)))))        )
 
-(emacspeak-url-template-define
- "Periodicals from Bookshare"
- "http://www.bookshare.org/web/DownloadPeriodical.html?publishtitleid=%s&date=%s&format=1"
- (list
-  "Periodical: "
-  'emacspeak-url-template-calendar-to-seconds)
- nil
- "Fetch periodical from Bookshare.")
-
 ;;}}}
 ;;{{{ shoutcast
 (defvar emacspeak-url-template-shoutcast-history nil
@@ -432,9 +400,9 @@ dont-url-encode if true then url arguments are not url-encoded "
  "BBC iPlayer"
  #'(lambda (url)
      (emacspeak-webutils-with-xsl-environment
-     (expand-file-name "bbc-iplayer.xsl" emacspeak-xslt-directory)
-     nil emacspeak-xslt-options
-     (browse-url url))))
+      (expand-file-name "bbc-iplayer.xsl" emacspeak-xslt-directory)
+      nil emacspeak-xslt-options
+      (browse-url url))))
 
 ;;}}}
 ;;{{{ bbc
@@ -501,7 +469,6 @@ dont-url-encode if true then url arguments are not url-encoded "
       "id(\"res0\")/.."
       url )))
 
-
 ;;; Google Realtime standalone:
 
 (emacspeak-url-template-define
@@ -524,11 +491,10 @@ dont-url-encode if true then url arguments are not url-encoded "
  nil
  "Display financial market summary."
  #'(lambda (url)
-     (emacspeak-we-extract-by-id-list
+     (emacspeak-we-extract-id-list-text
       (list "mktsumm" "sfe-mktsumm" )
       url 'speak)))
 
-
 ;;}}}
 ;;{{{ google CSE and Google Reader:
 (defcustom emacspeak-url-template-reading-list-opml nil
@@ -591,9 +557,9 @@ dont-url-encode if true then url arguments are not url-encoded "
 
 (defun emacspeak-url-template-setup-content-filter ()
   "Set up content filter in displayed page."
-  (declare (special emacspeak-we-xpath-filter))
+  (declare (special emacspeak-we-xpath-filter emacspeak-we-paragraphs-xpath-filter))
   (setq emacspeak-we-xpath-filter
-        emacspeak-we-recent-xpath-filter))
+        emacspeak-we-paragraphs-xpath-filter))
 
 ;;}}}
 ;;{{{ webmaster tools
@@ -739,7 +705,7 @@ http://www.google.com/calendar/a/<my-corp>/m?output=xhtml"
  "http://www.google.com/patents?ie=ISO-8859-1&q=%s"
  (list "Google For Patents: ")
  #'(lambda nil
-     (search-forward "Patent Search" nil t)
+     (search-forward " Patent Search" nil t)
      (beginning-of-line)
      (emacspeak-speak-rest-of-buffer))
  "Perform patent search via Google")
@@ -785,7 +751,9 @@ http://www.google.com/calendar/a/<my-corp>/m?output=xhtml"
 (emacspeak-url-template-define
  "YouTube Results"
  "http://gdata.youtube.com/feeds/api/videos?vq=%s"
- (list "YouTube:")
+ (list
+  #'(lambda ()
+      (gweb-google-autocomplete-with-corpus "youtube")))
  #'(lambda ()
      (declare (special emacspeak-we-url-executor))
      (setq emacspeak-we-url-executor
@@ -993,20 +961,20 @@ Here are some examples:
  "Google Scholar"
  "http://scholar.google.com/scholar?ie=UTF-8&oe=UTF-8&hl=en&btnG=Search&num=25&q=%s"
  (list "Google Scholar Search: ")
- #'(lambda nil
-     (search-forward "Results" nil t)
-     (emacspeak-speak-line))
- "Google Scholar Search")
+ nil
+ "Google Scholar Search"
+ #'(lambda (url)
+     (emacspeak-we-extract-by-class "gs_r" url 'speak)))
 
 ;;}}}
 ;;{{{ google images
 
 (emacspeak-url-template-define
  "Google Image Search"
- "http://images.google.com/images?hl=en&tab=wi&ie=UTF-8&q=%s"
+ "http://images.google.com/images?hl=en&source=hp&q=%s&btnG=Search+Images&gbv=1"
  (list "Google Image Search: ")
  #'(lambda ()
-     (search-forward "Showing" nil t)
+     (search-forward "results" nil t)
      (emacspeak-speak-line))
  "Google Image Search"
  #'(lambda (url)
@@ -1018,14 +986,14 @@ Here are some examples:
 
 (emacspeak-url-template-define
  "BlogSearch Google"
- "http://blogsearch.google.com/blogsearch_feeds?hl=en&q=%s&ie=utf-8&num=25&output=atom"
+ "http://www.google.com/search?q=%s&hl=en&tbm=blg&output=atom"
  (list "Google Blog Search: ")
  nil
  "Google Blog Search"
  'emacspeak-webutils-atom-display)
 (emacspeak-url-template-define
  "Recent BlogSearch Google"
- "http://blogsearch.google.com/blogsearch_feeds?hl=en&q=%s&ie=utf-8&num=25&scoring=d&output=atom"
+ "http://www.google.com/search?q=%s&hl=en&tbm=blg&scoring=d&output=atom"
  (list "Google Blog Search: ")
  nil
  "Google Blog Search"
@@ -1108,26 +1076,25 @@ from English to German.")
  "Google Glossary lookup.")
 
 (emacspeak-url-template-define
- "1Box Google"
- "https://www.google.com/search?q=%s"
+ "Google Results"
+ "http://www.google.com/search?q=%s&num=25"
  (list 'gweb-google-autocomplete)
  nil
- "Show 1box result from Google."
+ "Show just results and nav bar."
  #'(lambda (url)
-     (emacspeak-we-extract-by-class-list
-      (list "rbt" "e" "std" "med")
+     (emacspeak-we-extract-by-id-list
+      (list "subform_ctrl" "res" "nav")
       url 'speak)))
 
-
 (emacspeak-url-template-define
- "Answers from Google Squared"
- "https://www.google.com/search?q=%s"
+ "1Box Google"
+ "http://www.google.com/search?q=%s"
  (list 'gweb-google-autocomplete)
  nil
- "Answers from Google Squared snippets."
+ "Show 1box result from Google. Actually now shows just the results."
  #'(lambda (url)
      (emacspeak-we-extract-by-id
-      "ires"
+      "res"
       url 'speak)))
 
 (emacspeak-url-template-define
@@ -1181,7 +1148,7 @@ from English to German.")
  "http://print.google.com/print?oi=print&q=%s"
  (list "Google Print Search:")
  #'(lambda nil
-     (search-forward "Print Books" nil t)
+     (search-forward "Print  Books" nil t)
      (emacspeak-speak-rest-of-buffer))
  "Google Print Search")
 
@@ -1275,7 +1242,7 @@ from English to German.")
 
 (emacspeak-url-template-define
  "Tech News From CNet"
- "http://rss.com.com/2547-12-0-20.xml"
+ "http://news.com.com/2547-1_3-0-5.xml"
  nil
  'emacspeak-url-template-setup-content-filter
  "Display tech news from CNET"
@@ -1322,6 +1289,18 @@ from English to German.")
      (emacspeak-we-extract-table-by-match "Maneuvers"
                                           url 'speak)))
 
+;;}}}
+;;{{{ bing rss
+
+(emacspeak-url-template-define
+ "Bing RSS"
+ "http://www.bing.com/search?go=&qs=ns&form=QBLH&format=rss&q=%s"
+ (list "Bing For: ")
+ nil
+ "RSS Feed of Bing Results."
+ #'(lambda (url)
+     (emacspeak-webutils-rss-display url)))
+
 ;;}}}
 ;;{{{ yahoo daily news
 (emacspeak-url-template-define
@@ -1600,7 +1579,7 @@ name of the list.")
  #'(lambda (url)
      (emacspeak-we-extract-by-id
       "wsod_marketsOverview" 
-       url 'speak)))
+      url 'speak)))
 
 (emacspeak-url-template-define
  "CNN Content "
@@ -1639,144 +1618,7 @@ name of the list.")
  "Read pulpit from PBS. Published on the Thursday of the week."
  #'(lambda (url)
      (emacspeak-we-xslt-filter
-      "//p" url 'speak)))
-
-;;}}}
-;;{{{  NPR programs
-
-(emacspeak-url-template-define
- "American Life On Demand."
-                                        ;"http://www.wbez.org/ta/%s.rm"
- "http://www.thislife.org/ra/%s.ram"
- (list "Episode: ")
- nil
- "Play This American Life  shows on demand."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "Wait Wait, Dont Tell Me (NPR)"
- "http://www.npr.org/dmg/dmg.php?mediaURL=/waitwait/%s_waitwait&mediaType=RM"
- (list
-  #'(lambda ()
-      (emacspeak-url-template-collect-date "Date: (Saturdays)"
-                                           "%Y%m%d")))
- nil
- "Play Wait, Wait Dont Tell Me from NPR."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "NPR On Demand"
- "http://www.npr.org/dmg/dmg.php?prgCode=%s&showDate=%s&segNum=%s&mediaPref=RM"
- (list
-  #'(lambda ()
-      (upcase (read-from-minibuffer "Program code:")))
-  #'(lambda ()
-      (emacspeak-url-template-collect-date "Date:"
-                                           "%d-%b-%Y"))
-  "Segment:")
- nil
- "Play NPR shows on demand.
-Program is specified as a program code:
-
-ME              Morning Edition
-ATC             All Things Considered
-day             Day To Day
-newsnotes       News And Notes
-totn            Talk Of The Nation
-fa              Fresh Air
-wesat           Weekend Edition Saturday
-wesun           Weekend Edition Sunday
-fool            The Motley Fool
-
-Segment is specified as a two digit number --specifying a blank value
-plays entire program."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)
-     (emacspeak-xslt-view
-      (expand-file-name "smil-anchors.xsl"
-                        emacspeak-xslt-directory)
-      url)))
-
-(emacspeak-url-template-define
- "All Things Considered Stream from NPR"
-
- "http://www.npr.org/dmg/dmg.php?prgCode=ATC&showDate=%s&segNum=&mediaPref=RM"
- (list
-  #'(lambda ()
-      (emacspeak-url-template-collect-date "Date:"
-                                           "%d-%b-%Y")))
- nil
- "Play NPR All Things Considered stream."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "Talk Of The Nation  Stream from NPR"
- "http://www.npr.org/ramfiles/totn/%s.totn.ram"
- (list 'emacspeak-url-template-date-YearMonthDate)
- nil
- "Play NPR Talk Of The Nation  stream."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "Morning Edition Stream from NPR"
- "http://www.npr.org/dmg/dmg.php?prgCode=ME&showDate=%s&segNum=&mediaPref=RM"
- (list
-  #'(lambda ()
-      (emacspeak-url-template-collect-date "Date:"
-                                           "%d-%b-%Y")))
- nil
- "Play NPR Morning Edition  stream."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "Motley Fool Radio from NPR"
- "http://www.npr.org/dmg/dmg.php?prgCode=FOOL&showDate=%s&segNum=&mediaPref=RM"
- (list
-  #'(lambda ()
-      (emacspeak-url-template-collect-date "Date:"
-                                           "%d-%b-%Y")))
- nil
- "Play NPR Motley Fool   stream."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "Talk Of The Nation from NPR"
- "rtsp://audio.npr.org/totn/%s_totn_%s.rm"
- (list
-  'emacspeak-url-template-date-YearMonthDate
-  "Segment: ")
- nil
- "Play NPR Talk Of The Nation segment."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "All Things Considered from NPR"
- "rtsp://audio.npr.org/atc/%s_atc_%s.rm"
- (list
-  'emacspeak-url-template-date-YearMonthDate
-  "Segment: ")
- nil
- "Play All Things Considered segment."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
-
-(emacspeak-url-template-define
- "Morning Edition from NPR"
- "rtsp://audio.npr.org/me/%s_me_%s.rm"
- (list
-  'emacspeak-url-template-date-YearMonthDate
-  "Segment:")
- nil
- "Play Morning Edition segment."
- #'(lambda (url)
-     (funcall emacspeak-media-player url 'play-list)))
+      emacspeak-we-recent-xpath-filter url 'speak)))
 
 ;;}}}
 ;;{{{  The Linux Show
@@ -2122,14 +1964,6 @@ Meerkat realy needs an xml-rpc method for getting this.")
 
 ;;}}}
 ;;{{{  flight arrival
-(emacspeak-url-template-define
- "Flight Tracker"
- "http://tracker.flightview.com/fvAirwise/fvCPL.exe?qtype=htm&AL=%s&acid=%s&FIND1=Find+flight"
- (list "Airline: " "Flight number: ")
- #'(lambda nil
-     (search-forward "Airline: " nil t)
-     (emacspeak-speak-line))
- "Display flight arrival and departure information.")
 
 ;;}}}
 ;;{{{ weather underground
@@ -2259,11 +2093,24 @@ Meerkat realy needs an xml-rpc method for getting this.")
  "Show table of recent quakes."
  #'(lambda (url)
      (emacspeak-we-xslt-filter "//tr[position() < 10]"
-			       url
-			       'speak)))
+                               url
+                               'speak)))
 
 ;;}}}
+;;{{{  Radio station streams 
 
+(emacspeak-url-template-define
+ "StreamWorld Radio"
+ "http://provisioning.streamtheworld.com/pls/%s.pls"
+ (list
+  #'(lambda () (upcase (read-from-minibuffer "Station ID: "))))
+ nil
+ "Play radio stream.
+See http://www.cbsradio.com/streaming/index.html for a list of CBS  stations that use StreamTheWorld."
+ #'(lambda (url)
+     (emacspeak-m-player url 'playlist)))
+
+;;}}}
 ;;}}}
 ;;{{{ Interactive commands
 
@@ -2332,7 +2179,6 @@ Optional interactive prefix arg displays documentation for specified resource."
                            emacspeak-url-template-table
                            nil
                            'must-match))
-    (pop minibuffer-history)
     (cond
      (documentation (emacspeak-url-template-help-internal name))
      (t
@@ -2383,9 +2229,9 @@ Each URL template carries out the following steps:
   customizations.
 @end itemize
 
-As an example, the URL templates that enable access to NPR media
-streams prompt for a program id and date, and automatically
-launch the realmedia player after fetching the resource.\n\n"
+As an example, the URL templates that enable access to map directions
+prompt for address and automatically
+speak the relevant results.\n\n"
     (mapconcat #'key-description
                (where-is-internal
                 'emacspeak-url-template-fetch)
@@ -2414,4 +2260,3 @@ launch the realmedia player after fetching the resource.\n\n"
 ;;; end:
 
 ;;}}}
-
