@@ -1,5 +1,5 @@
 ;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el 6616 2010-10-06 23:58:16Z tv.raman.tv $
+;;; $Id: emacspeak-vm.el 7323 2011-10-26 00:50:39Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -72,8 +72,7 @@ Note that some badly formed mime messages  cause trouble."
   (when dtk-allcaps-beep
     (dtk-toggle-allcaps-beep))
   (emacspeak-dtk-sync)
-  (when emacspeak-vm-voice-lock-messages
-    (voice-lock-mode 1)))
+  (when emacspeak-vm-voice-lock-messages))
 
 ;;}}}
 ;;{{{ inline helpers
@@ -162,6 +161,7 @@ Note that some badly formed mime messages  cause trouble."
 (defun emacspeak-vm-summarize-message ()
   "Summarize the current vm message. "
   (declare (special vm-message-pointer
+                    smtpmail-local-domain
                     emacspeak-vm-headers-strip-octals
                     emacspeak-vm-user-full-name emacspeak-vm-user-login-name))
   (when vm-message-pointer
@@ -380,8 +380,7 @@ Then speak the screenful. "
   "Provide an auditory icon if requested"
   (when (interactive-p)
     (emacspeak-auditory-icon 'close-object)
-    (message "%s"
-             (emacspeak-speak-mode-line))))
+    (emacspeak-speak-mode-line)))
 
 ;;}}}
 ;;{{{ catching up on folders
