@@ -1,5 +1,5 @@
 ;;; emacspeak-w3.el --- Speech enable W3 WWW browser -- includes ACSS Support
-;;; $Id: emacspeak-w3.el 6342 2009-10-20 19:12:40Z tv.raman.tv $
+;;; $Id: emacspeak-w3.el 7733 2012-05-03 02:12:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak enhancements for W3
 ;;; Keywords: Emacspeak, W3, WWW
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -496,11 +496,6 @@ element. "
     (message (mapconcat #'identity
                         (widget-get (widget-at (point)) :class ) " "))))
 
-;;}}}
-;;{{{ load realaudio if available
-(when (locate-library "emacspeak-realaudio")
-  (require 'emacspeak-realaudio))
-
 ;;}}}
 ;;{{{ url rewrite
 
@@ -531,7 +526,8 @@ element. "
 
 (defadvice w3-notify-when-ready (after emacspeak pre act comp)
   "Call w3 post-processor hook if set."
-  (emacspeak-webutils-run-post-process-hook))
+  (let ((inhibit-read-only t))
+    (emacspeak-webutils-run-post-process-hook)))
 
 ;;}}}
 ;;{{{ advice focus on cell
@@ -596,6 +592,13 @@ element. "
     ad-do-it
     ad-return-value))
 
+(defadvice url-cookie-write-file
+  (around emacspeak pre act comp)
+  "silence spoken messages."
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it
+    ad-return-value))
+
 (defadvice url-lazy-message
   (around emacspeak pre act comp)
   "silence spoken messages."
@@ -613,7 +616,6 @@ element. "
 ;;; this will go away
 (defalias 'make-dtk-speech-style 'make-acss)
 (defalias 'dtk-personality-from-speech-style 'acss-personality-from-speech-style)
-(provide 'dtk-css-speech)
 
 ;;}}}
 ;;{{{ define pronunciation for document's base URI
@@ -714,7 +716,7 @@ If a rewrite rule is defined in the current buffer, we change
   "Options to pass to tidy program"
   :type '(repeat string)
   :group 'emacspeak-w3)
-
+;;;###autoload
 (defcustom emacspeak-w3-tidy-html t
   "Tidy HTML before rendering."
   :type 'boolean
@@ -802,6 +804,62 @@ HTML."
       ad-do-it
     (error nil)))
 
+;;}}}
+;;{{{ handle xml as HTML:
+;;; fix mm-inline-types
+(require 'mm-decode)
+(declaim (special  mm-inline-media-tests))
+(loop for mm in
+      '("application/xml"
+        "application/xml+xhtml"
+        "text/xml")
+      do
+      (pushnew
+       (list mm
+             'mm-inline-text-html-render-with-w3
+             #'(lambda (&rest args) mm-text-html-renderer))
+       mm-inline-media-tests))
+
+;;}}}
+;;{{{ fix error in insert-char call for emacs 24
+
+(defadvice insert-char (around fix-w3-error pre act comp)
+  "Handle erroneous call from W3."
+  (condition-case nil
+      ad-do-it
+    (error nil)))
+
+;;}}}
+;;{{{ Fix url breakage in emacs 24 GIT:
+
+Tue Apr 24 17:33:27 PDT 2012
+;;; pattern: http://www.google.com/url?q=http://emacspeak.sourceforge.net/&sa=U&ei=GceWT42_EY_ViALW84nlCQ&ved=0CBIQFjAA&usg=AFQjCNGz91Z7Yz9dPVoKPP6HVGZ0UqFhRA
+;;; prefix: http://www.google.com/url?q=
+;;; Suffix: &sa=...
+
+(defsubst emacspeak-w3-canonicalize-google-result-url (url)
+  "Strip out the actual result URL from the redirect wrapper."
+  (declare (special emacspeak-websearch-google-use-https))
+  (substring url
+             (if emacspeak-websearch-google-use-https 29 28)
+             (string-match "&sa=" url)))
+
+(defsubst emacspeak-w3-google-result-url-prefix ()
+  "Return prefix of result urls."
+  (declare (special emacspeak-websearch-google-use-https))
+  (format "%s://www.google.com/url?q="
+          (if emacspeak-websearch-google-use-https "https" "http")))
+
+(defadvice url-retrieve-internal (before fix-bug pre act comp)
+  "Fix bug in handling of google result urls."
+  (let ((u (ad-get-arg 0)))
+    (when (string-prefix-p (emacspeak-w3-google-result-url-prefix) u)
+      (ad-set-arg 0 (emacspeak-w3-canonicalize-google-result-url u)))))
+
+(defun foo (x y)
+  "show x"
+  (message (concat x y)))
+
 ;;}}}
 ;;{{{  emacs local variables
 
