@@ -1,5 +1,5 @@
 ;;; emacspeak-webspace.el --- Webspaces In Emacspeak
-;;; $Id: emacspeak-webspace.el 6617 2010-10-07 15:33:52Z tv.raman.tv $
+;;; $Id: emacspeak-webspace.el 7720 2012-04-25 02:46:26Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: WebSpace provides smart updates from the Web.
 ;;; Keywords: Emacspeak, Audio Desktop webspace
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{ Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -60,7 +60,7 @@
 
 ;;; Define a derived-mode called WebSpace that is generally useful for hypetext display.
 
-(define-derived-mode emacspeak-webspace-mode fundamental-mode
+(define-derived-mode emacspeak-webspace-mode special-mode
   "Webspace Interaction"
   "Major mode for Webspace interaction.\n\n
 \\{emacspeak-webspace-mode-map}")
@@ -80,13 +80,15 @@
         ("b" emacspeak-webspace-previous-link)
         ("y" emacspeak-webspace-yank-link)
         ("A"emacspeak-webspace-atom-view)
+        ("r" greader-reading-list)
         ("R" emacspeak-webspace-rss-view)
         ("F" emacspeak-webspace-feed-view)
         ("t" emacspeak-webspace-transcode)
         ("\C-m" emacspeak-webspace-open)
         ("." emacspeak-webspace-filter)
         ("n" next-line)
-        ("p" previous-line))
+        ("p" previous-line)
+        ("g" emacspeak-webspace-reader-refresh))
       do
       (emacspeak-keymap-update  emacspeak-webspace-mode-map k))
 
@@ -106,17 +108,18 @@
 (defun emacspeak-webspace-atom-view ()
   "View Atom feed."
   (interactive)
+  (emacspeak-webutils-autospeak)
   (emacspeak-webspace-act-on-link 'emacspeak-webutils-atom-display))
 
 (defun emacspeak-webspace-rss-view ()
   "View RSS feed."
   (interactive)
+  (emacspeak-webutils-autospeak)
   (emacspeak-webspace-act-on-link 'emacspeak-webutils-rss-display))
 
 (defun emacspeak-webspace-feed-view ()
   "View  feed using gfeeds."
   (interactive)
-  (emacspeak-webutils-autospeak)
   (emacspeak-webspace-act-on-link 'gfeeds-view))
 
 ;;;###autoload
@@ -129,9 +132,8 @@
       (kill-new link)
       (emacspeak-auditory-icon 'yank-object)
       (message link))
-     (t (error "No link under point")))))k
+     (t (error "No link under point")))))
 
-  
 (defadvice gfeeds-view (around emacspeak pre act comp)
   "Automatically speak display."
   (when (interactive-p)
@@ -139,12 +141,10 @@
   ad-do-it
   ad-return-value)
 
-    
 ;;;###autoload
 (defun emacspeak-webspace-open ()
   "Open headline at point by following its link property."
   (interactive)
-  (emacspeak-webutils-autospeak)
   (emacspeak-webspace-act-on-link 'browse-url))
 
 ;;;###autoload
@@ -154,7 +154,7 @@
   (let ((link (get-text-property (point) 'link)))
     (if link
         (emacspeak-we-xslt-filter
-         "//p"
+         emacspeak-we-recent-xpath-filter
          link 'speak)
       (message "No link under point."))))
 ;;;###autoload
@@ -222,6 +222,7 @@ Generates auditory and visual display."
       '(
         ("w" emacspeak-webspace-weather)
         ("h" emacspeak-webspace-headlines)
+        ("r" greader-reading-list)
         )
       do
       (define-key emacspeak-webspace-keymap (first k) (second k)))
@@ -339,11 +340,11 @@ Updated headlines found in emacspeak-webspace-headlines."
              emacspeak-url-template-weather-city-state)
     (with-local-quit
       (format "%s at %s"
-      (first
-       (gfeeds-titles
-        (format emacspeak-webspace-weather-url-template
-                emacspeak-url-template-weather-city-state)))
-      emacspeak-url-template-weather-city-state))))
+              (first
+               (gfeeds-titles
+                (format emacspeak-webspace-weather-url-template
+                        emacspeak-url-template-weather-city-state)))
+              emacspeak-url-template-weather-city-state))))
 
 (defvar emacspeak-webspace-current-weather nil
   "Holds cached value of current weather conditions.")
@@ -389,48 +390,57 @@ Updated weather is found in `emacspeak-webspace-current-weather'."
   "Prepare Reader buffer."
   (declare (special emacspeak-webspace-reader-buffer))
   (let ((subscriptions (greader-subscriptions))
-          (buffer (get-buffer-create emacspeak-webspace-reader-buffer))
-          (inhibit-read-only t)
-          (start nil))
-      (save-excursion
-        (set-buffer buffer)
-        (erase-buffer)
-        (setq buffer-undo-list t)
-        (goto-char (point-min))
-        (insert
-         (format "Google Reader %d\n"
-                 (length subscriptions)))
-        (setq start (point))
-        (loop for feed across subscriptions
-              and i from 1
-              do
-              (insert
-               (format "%d. %s\n"
-                       i
-                       (cdr (assoc 'title feed))))
-              (put-text-property start (point)
-                                 'link (greader-id-to-url (cdr
-                                                           (assoc
-                                                            'id
-                                                            feed))))
-              (setq start (point)))
-        (setq buffer-read-only t)
-	(emacspeak-webspace-mode)
+        (buffer (get-buffer-create emacspeak-webspace-reader-buffer))
+        (inhibit-read-only t)
+        (start nil))
+    (save-excursion
+      (set-buffer buffer)
+      (erase-buffer)
+      (setq buffer-undo-list t)
+      (goto-char (point-min))
+      (insert
+       (format "Google Reader %d\n"
+               (length subscriptions)))
+      (setq start (point))
+      (loop for feed across subscriptions
+            and i from 1
+            do
+            (insert
+             (format "%d. %s\n"
+                     i
+                     (cdr (assoc 'title feed))))
+            (put-text-property start (point)
+                               'link (greader-id-to-url (cdr
+                                                         (assoc
+                                                          'id
+                                                          feed))))
+            (setq start (point)))
+      (setq buffer-read-only t)
+      (emacspeak-webspace-mode)
       (local-set-key "u" 'emacspeak-webspace-reader-unsubscribe))
-      buffer))
+    buffer))
 
 ;;;###autoload 
-(defun emacspeak-webspace-reader ()
-  "Display Google Reader Feed list in a WebSpace buffer."
-  (interactive)
+(defun emacspeak-webspace-reader (&optional refresh)
+  "Display Google Reader Feed list in a WebSpace buffer.
+Optional interactive prefix arg forces a refresh."
+  (interactive "P")
   (declare (special emacspeak-webspace-reader-buffer))
-  (unless (buffer-live-p  (get-buffer emacspeak-webspace-reader-buffer))
+  (when (or refresh
+            (not (buffer-live-p  (get-buffer emacspeak-webspace-reader-buffer))))
     (emacspeak-webspace-reader-create))
   (switch-to-buffer emacspeak-webspace-reader-buffer)
   (goto-char (point-min))
   (emacspeak-speak-mode-line)
   (emacspeak-auditory-icon 'open-object))
 
+;;;###autoload
+(defun emacspeak-webspace-reader-refresh ()
+  "Refresh Reader."
+  (interactive )
+  (emacspeak-webspace-reader 'refresh)  (emacspeak-speak-mode-line)
+  (emacspeak-auditory-icon 'open-object))
+
 ;;;###autoload
 (defun emacspeak-webspace-reader-unsubscribe ()
   "Unsubscribe to link under point."
