@@ -1,5 +1,5 @@
 ;;; emacspeak-webutils.el --- Common Web Utilities For Emacspeak
-;;; $Id: emacspeak-webutils.el 6529 2010-06-24 16:07:57Z tv.raman.tv $
+;;; $Id: emacspeak-webutils.el 7571 2012-03-12 22:54:24Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak Webutils
 ;;; Keywords: Emacspeak, web
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -82,9 +82,10 @@ Note that the Web browser should reset this hook after using it.")
   (declare (special emacspeak-web-post-process-hook))
   (when     emacspeak-web-post-process-hook
     (condition-case nil
-         (run-hooks  'emacspeak-web-post-process-hook)
-      (error 
-      (setq emacspeak-web-post-process-hook nil)))
+        (let ((inhibit-read-only t))
+          (run-hooks  'emacspeak-web-post-process-hook))
+      (error  (message "Caught error  in post-process hook.")
+              (setq emacspeak-web-post-process-hook nil)))
     (setq emacspeak-web-post-process-hook nil)))
 
 ;;}}}
@@ -126,19 +127,20 @@ Note that the Web browser should reset this hook after using it.")
   (add-hook 'emacspeak-web-post-process-hook
             #'(lambda nil
                 (declare (special emacspeak-we-xpath-filter))
-                (setq emacspeak-we-xpath-filter
-                      "//p")
-                (emacspeak-speak-buffer))
+                (let ((inhibit-read-only t))
+                  (setq emacspeak-we-xpath-filter
+                        emacspeak-we-paragraphs-xpath-filter)
+                  (emacspeak-speak-buffer)))
             'at-end))
 
 (defsubst emacspeak-webutils-cache-google-query(query)
   "Setup post process hook to cache google query when rendered."
   (declare (special emacspeak-google-query))
   (let ((cache
-  (eval `(function
-          (lambda nil
-             (setq emacspeak-google-query ,query))))))
-  (add-hook 'emacspeak-web-post-process-hook cache 'at-end)))
+         (eval `(function
+                 (lambda nil
+                   (setq emacspeak-google-query ,query))))))
+    (add-hook 'emacspeak-web-post-process-hook cache 'at-end)))
 
 (defsubst emacspeak-webutils-cache-google-toolbelt(belt)
   "Setup post process hook to cache google toolbelt when rendered."
@@ -197,16 +199,20 @@ SPEAKER is a function to call to speak relevant information.
 ARGS specifies additional arguments to SPEAKER if any."
   (declare (special emacspeak-web-post-process-hook))
   (when (emacspeak-webutils-supported-p)
-    (add-hook  'emacspeak-web-post-process-hook
-               (eval
-                `(function
-                  (lambda nil
-                    (cond
-                     ((search-forward ,locator nil t)
-                      (recenter 0)
-                      (apply(quote ,speaker) ,args))
-                     (t (message "Your search appears to have failed."))))))
-               'at-end)))
+    (add-hook
+     'emacspeak-web-post-process-hook
+     (eval
+      `(function
+        (lambda nil
+          (let ((inhibit-read-only t))
+            (condition-case nil
+                (cond
+                 ((search-forward ,locator nil t)
+                  (recenter 0)
+                  (apply(quote ,speaker) ,args))
+                 (t (message "Your search appears to have failed.")))
+              (error nil))))))
+     'at-end)))
 
 ;;}}}
 ;;{{{ helper macros:
@@ -405,12 +411,13 @@ instances."
       (error "Title not found in body."))))
 
 ;;;###autoload
-(defun emacspeak-webutils-play-media-at-point ()
-  "Play media url under point "
-  (interactive )
+(defun emacspeak-webutils-play-media-at-point (&optional  playlist-p)
+  "Play media url under point.
+Optional interactive prefix arg `playlist-p' says to treat the link as a playlist. "
+  (interactive "P" )
   (let ((url (funcall emacspeak-webutils-url-at-point)))
     (message "Playing media  URL under point")
-    (funcall emacspeak-media-player  url)))
+    (funcall  emacspeak-media-player  url  playlist-p)))
 
 ;;;###autoload
 (defun emacspeak-webutils-view-feed-via-google-reader ()
@@ -450,9 +457,8 @@ instances."
      ((null buffer)
       (message "Nothing to display."))
      (t
-      (emacspeak-webutils-without-xsl
-       (save-excursion
-         (set-buffer buffer)
+      (with-current-buffer buffer
+        (emacspeak-webutils-without-xsl
          (goto-char (point-min))
          (search-forward "\n\n")
          (delete-region (point-min) (point))
@@ -536,14 +542,12 @@ unescape HTML tags."
 
 ;;;###autoload
 
-  
 (defun emacspeak-webutils-open-subscribed-feeds ()
   "Feed list specified by OPML file customized via emacspeak-my-subscribed-feeds"
   (interactive)
   (declare (special emacspeak-my-subscribed-feeds))
   (emacspeak-opml-display emacspeak-my-subscribed-feeds))
 
-
 ;;;###autoload
 (defun emacspeak-rss-browse (feed)
   "Browse specified RSS feed."
@@ -632,7 +636,6 @@ Stack is a list of the form ((element-name (attribute-alist)))."
     (nreverse (delq nil props))))
 
 ;;}}}
-   
 
 (provide 'emacspeak-webutils)
 ;;{{{ end of file
