@@ -1,5 +1,5 @@
 ;;; emacspeak-xslt.el --- Implements Emacspeak  xslt transform engine
-;;; $Id: emacspeak-xslt.el 6492 2010-05-14 20:48:09Z tv.raman.tv $
+;;; $Id: emacspeak-xslt.el 7668 2012-04-07 17:07:15Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  xslt transformation routines
 ;;; Keywords: Emacspeak,  Audio Desktop XSLT
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -160,9 +160,12 @@ part of the libxslt package."
     (current-buffer)))
 
 ;;;###autoload
-(defsubst emacspeak-xslt-run (xsl start end)
-  "Run xslt on region, and return output filtered by sort -u"
+(defsubst emacspeak-xslt-run (xsl &optional start end)
+  "Run xslt on region, and return output filtered by sort -u.
+Region defaults to entire buffer."
   (declare (special emacspeak-xslt-program emacspeak-xslt-options))
+  (or start (setq start (point-min)))
+  (or end (setq end (point-max)))
   (let ((coding-system-for-read 'utf-8)
         (coding-system-for-write 'utf-8)
         (buffer-file-coding-system 'utf-8))
@@ -311,18 +314,20 @@ part of the libxslt package."
 ;;;###autoload
 (defun emacspeak-xslt-view-file(style file)
   "Transform `file' using `style' and preview via browse-url."
-  (interactive "FStyle:\nFFile:")
+  (interactive
+   (list
+    (read-file-name "Style File: "
+                    emacspeak-xslt-directory)
+    (read-file-name "File:" default-directory)))
   (with-temp-buffer
     (let ((coding-system-for-read 'utf-8)
           (coding-system-for-write 'utf-8)
           (buffer-file-coding-system 'utf-8))
       (insert-file file)
-      (shell-command-on-region
-       (point-min) (point-max)
-       (format "%s --param base %s  %s - %s "
-               emacspeak-xslt-program
-                 (format "\"'file://%s'\""
-                         (expand-file-name file))
+      (shell-command
+       (format "%s   --novalid --nonet --param base %s  %s  %s  2>/dev/null"
+               emacspeak-xslt-program 
+               (format "\"'file://%s'\"" (expand-file-name file))
                (expand-file-name style)
                (expand-file-name file))
        (current-buffer) 'replace)
@@ -343,7 +348,7 @@ part of the libxslt package."
    style
    nil
    emacspeak-xslt-options
-   url))
+   (browse-url url)))
 
 ;;;###autoload
 (defun emacspeak-xslt-view-xml (style url &optional unescape-charent)
@@ -361,8 +366,7 @@ part of the libxslt package."
            (cons "base"
                  (format "\"'%s'\""
                          url))))))
-    (when (interactive-p)
-      (emacspeak-webutils-autospeak))
+    (when (interactive-p) (emacspeak-webutils-autospeak))
     (save-excursion
       (set-buffer src-buffer)
       (when unescape-charent
@@ -391,7 +395,6 @@ part of the libxslt package."
        (browse-url-of-buffer)))
     (kill-buffer src-buffer)))
 
-
 ;;}}}
 (provide 'emacspeak-xslt)
 ;;{{{ end of file
