@@ -1,5 +1,5 @@
 ;;; emacspeak.el --- Emacspeak -- The Complete Audio Desktop
-;;; $Id: emacspeak.el 6577 2010-09-02 15:55:57Z tv.raman.tv $
+;;; $Id: emacspeak.el 7695 2012-04-18 15:34:29Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak: A speech interface to Emacs
 ;;; Keywords: Emacspeak, Speech, Dectalk,
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2009, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -151,7 +151,6 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "bookmark" 'emacspeak-bookmark)
 (emacspeak-do-package-setup "bmk-mgr" 'emacspeak-bmk-mgr)
 (emacspeak-do-package-setup "browse-kill-ring" 'emacspeak-browse-kill-ring )
-(emacspeak-do-package-setup "buff-sel" 'emacspeak-buff-sel)
 (emacspeak-do-package-setup "bs" 'emacspeak-bs)
 (emacspeak-do-package-setup "buff-menu" 'emacspeak-buff-menu)
 (emacspeak-do-package-setup "cc-mode" 'emacspeak-c)
@@ -164,6 +163,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "cmuscheme" 'emacspeak-cmuscheme)
 (emacspeak-do-package-setup "compile" 'emacspeak-compile)
 (emacspeak-do-package-setup "cperl-mode" 'emacspeak-cperl)
+(emacspeak-do-package-setup "pianobar" 'emacspeak-pianobar)
 (emacspeak-do-package-setup "proced" 'emacspeak-proced)
 (emacspeak-do-package-setup "ecb" 'emacspeak-ecb)
 (emacspeak-do-package-setup "cus-edit" 'emacspeak-custom)
@@ -187,6 +187,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "enriched" 'emacspeak-enriched)
 (emacspeak-do-package-setup "facemenu" 'emacspeak-facemenu)
 (emacspeak-do-package-setup "find-dired" 'emacspeak-find-dired)
+(emacspeak-do-package-setup "find-things-fast" 'emacspeak-ftf)
 (emacspeak-do-package-setup "find-func" 'emacspeak-find-func)
 (emacspeak-do-package-setup "flyspell" 'emacspeak-flyspell)
 (emacspeak-do-package-setup "folding" 'emacspeak-folding)
@@ -209,6 +210,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "jde" 'emacspeak-jde)
 (emacspeak-do-package-setup "js2" 'emacspeak-js2)
 (emacspeak-do-package-setup "kmacro" 'emacspeak-kmacro)
+(emacspeak-do-package-setup "magit" 'emacspeak-magit)
 (emacspeak-do-package-setup "make-mode" 'emacspeak-make-mode)
 (emacspeak-do-package-setup "man" 'emacspeak-man)
 (emacspeak-do-package-setup "moz" 'emacspeak-moz)
@@ -231,6 +233,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "pcvs" 'emacspeak-pcl-cvs)
 (emacspeak-do-package-setup "psgml" 'emacspeak-psgml)
 (emacspeak-do-package-setup "python-mode" 'emacspeak-python)
+(emacspeak-do-package-setup "python-mode" 'emacspeak-py)
 (emacspeak-do-package-setup "re-builder" 'emacspeak-re-builder)
 (emacspeak-do-package-setup "reftex" 'emacspeak-reftex)
 (emacspeak-do-package-setup "rmail" 'emacspeak-rmail)
@@ -241,7 +244,6 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "sigbegone" 'emacspeak-sigbegone)
 (emacspeak-do-package-setup "solitaire" 'emacspeak-solitaire)
 (emacspeak-do-package-setup "speedbar" 'emacspeak-speedbar)
-(emacspeak-do-package-setup "sawfish" 'emacspeak-sawfish)
 (emacspeak-do-package-setup "ses" 'emacspeak-ses)
 (emacspeak-do-package-setup "sql-mode" 'emacspeak-sql)
 (emacspeak-do-package-setup "sql" 'emacspeak-sql)
@@ -266,9 +268,10 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "twit" 'emacspeak-twit)
 (emacspeak-do-package-setup "twittering-mode" 'emacspeak-twittering)
 (emacspeak-do-package-setup "view" 'emacspeak-view)
-(emacspeak-do-package-setup "view-process-mode" 'emacspeak-view-process)
+(emacspeak-do-package-setup "view-pr" 'emacspeak-view-process)
 (emacspeak-do-package-setup "vm" 'emacspeak-vm)
 (emacspeak-do-package-setup "w3" 'emacspeak-w3)
+(emacspeak-do-package-setup "w3-display" 'emacspeak-w3)
 (emacspeak-do-package-setup "w3m" 'emacspeak-w3m)
 (emacspeak-do-package-setup "wdired" 'emacspeak-wdired)
 (emacspeak-do-package-setup "cus-edit" 'emacspeak-custom)
@@ -276,6 +279,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "widget" 'emacspeak-widget)
 (emacspeak-do-package-setup "windmove" 'emacspeak-windmove)
 (emacspeak-do-package-setup "winring" 'emacspeak-winring)
+(emacspeak-do-package-setup "woman" 'emacspeak-woman)
 
 ;;}}}
 ;;{{{  Submit bugs
@@ -392,11 +396,19 @@ sets punctuation mode to all, activates the dictionary and turns on split caps."
 ;;{{{ Emacspeak:
 
 ;;;###autoload
-(defcustom emacspeak-play-emacspeak-startup-icon nil
+(defcustom emacspeak-play-emacspeak-startup-icon t
   "If set to T, emacspeak plays its icon as it launches."
   :type 'boolean
   :group 'emacspeak)
-
+(defsubst emacspeak-play-startup-icon ()
+  "Play startup icon if requested."
+  (declare (special emacspeak-play-emacspeak-startup-icon))
+  (let ((player  (or (executable-find "mplayer")
+                     (executable-find "mpg321"))))
+    (when (and  emacspeak-play-emacspeak-startup-icon player)
+      (start-process "mp3" nil
+                     player
+                     (expand-file-name "emacspeak.mp3" emacspeak-sounds-directory)))))
 ;;;###autoload
 (defun emacspeak()
   "Starts the Emacspeak speech subsystem.  Use emacs as you
@@ -438,14 +450,11 @@ functions for details.   "
   (emacspeak-export-environment)
   (require 'emacspeak-personality)
   (dtk-initialize)
+  (tts-configure-synthesis-setup)
   (require 'emacspeak-redefine)
   (require 'emacspeak-advice)
   (require 'emacspeak-replace)
-  (when (and  emacspeak-play-emacspeak-startup-icon
-              (file-exists-p "/usr/bin/mpg123"))
-    (start-process "mp3" nil "mpg123"
-                   "-q"
-                   (expand-file-name "emacspeak.mp3" emacspeak-sounds-directory)))
+  (emacspeak-play-startup-icon)
   (emacspeak-sounds-define-theme-if-necessary emacspeak-sounds-default-theme)
   (when emacspeak-pronounce-load-pronunciations-on-startup
     (emacspeak-pronounce-load-dictionaries emacspeak-pronounce-dictionaries-file))
