@@ -1,6 +1,6 @@
 ;;;Auto generated
 
-;;;### (autoloads (g-auth-lifetime) "g-auth" "g-auth.el" (18706 8727))
+;;;### (autoloads (g-auth-lifetime) "g-auth" "g-auth.el" (20379 9054))
 ;;; Generated autoloads from g-auth.el
 
 (defvar g-auth-lifetime "4 hours" "\
@@ -13,7 +13,7 @@ Auth lifetime.")
 ;;;### (autoloads (gblogger-sign-in gblogger-sign-out gblogger-add-label
 ;;;;;;  gblogger-delete-entry gblogger-new-entry gblogger-edit-entry
 ;;;;;;  gblogger-atom-display gblogger-blog) "gblogger" "gblogger.el"
-;;;;;;  (19334 64028))
+;;;;;;  (20328 48785))
 ;;; Generated autoloads from gblogger.el
 
 (autoload 'gblogger-blog "gblogger" "\
@@ -58,12 +58,28 @@ Resets client so you can start with a different userid.
 
 \(fn)" t nil)
 
+;;;***
+
+;;;### (autoloads (gbooks-sign-in gbooks-sign-out) "gbooks" "gbooks.el"
+;;;;;;  (20336 46200))
+;;; Generated autoloads from gbooks.el
+
+(autoload 'gbooks-sign-out "gbooks" "\
+Resets client so you can start with a different userid.
+
+\(fn)" t nil)
+
+(autoload 'gbooks-sign-in "gbooks" "\
+Resets client so you can start with a different userid.
+
+\(fn)" t nil)
+
 ;;;***
 
 ;;;### (autoloads (gcal-sign-in gcal-sign-out gcal-emacs-calendar-setup
 ;;;;;;  gcal-show-event gcal-view gcal-calendar-agenda-days gcal-reject-event
 ;;;;;;  gcal-delete-event gcal-quickadd-event gcal-add-event gcal-user-email
-;;;;;;  gcal-default-user-email) "gcal" "gcal.el" (19683 6237))
+;;;;;;  gcal-default-user-email) "gcal" "gcal.el" (20328 48785))
 ;;; Generated autoloads from gcal.el
 
 (defvar gcal-default-user-email nil "\
@@ -132,7 +148,7 @@ Sign in, useful when changing to a different user profile.
 ;;;***
 
 ;;;### (autoloads (gcontacts-create gcontacts-initialize) "gcontacts"
-;;;;;;  "gcontacts.el" (19184 32877))
+;;;;;;  "gcontacts.el" (20328 48785))
 ;;; Generated autoloads from gcontacts.el
 
 (autoload 'gcontacts-initialize "gcontacts" "\
@@ -149,7 +165,7 @@ Create a new contact as specified.
 
 ;;;### (autoloads (gdocs-sign-in gdocs-sign-out gdocs-view-item gdocs-delete-item
 ;;;;;;  gdocs-add-collaborator gdocs-doclist) "gdocs" "gdocs.el"
-;;;;;;  (19691 64628))
+;;;;;;  (20328 48785))
 ;;; Generated autoloads from gdocs.el
 
 (autoload 'gdocs-doclist "gdocs" "\
@@ -186,8 +202,8 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads (gfeeds-view gfeeds-titles gfeeds-freshness) "gfeeds"
-;;;;;;  "gfeeds.el" (19230 43402))
+;;;### (autoloads (gfeeds-lookup-and-view gfeeds-view gfeeds-titles
+;;;;;;  gfeeds-freshness) "gfeeds" "gfeeds.el" (20328 48785))
 ;;; Generated autoloads from gfeeds.el
 
 (defsubst gfeeds-feed (feed-url) "\
@@ -215,10 +231,15 @@ Interactive prefix arg causes the feed url to be looked up given a Web site.
 
 \(fn URL &optional LOOKUP)" t nil)
 
+(autoload 'gfeeds-lookup-and-view "gfeeds" "\
+Lookup feed URL for a site and browse result.
+
+\(fn SITE)" t nil)
+
 ;;;***
 
 ;;;### (autoloads (gfinance-sign-in gfinance-sign-out gfinance-display-feed
-;;;;;;  gfinance-portfolios) "gfinance" "gfinance.el" (18706 8727))
+;;;;;;  gfinance-portfolios) "gfinance" "gfinance.el" (20328 48785))
 ;;; Generated autoloads from gfinance.el
 
 (autoload 'gfinance-portfolios "gfinance" "\
@@ -244,7 +265,7 @@ Resets client so you can start with a different userid.
 ;;;***
 
 ;;;### (autoloads (ghealth-sign-in ghealth-sign-out) "ghealth" "ghealth.el"
-;;;;;;  (19133 13120))
+;;;;;;  (20328 48785))
 ;;; Generated autoloads from ghealth.el
 
 (autoload 'ghealth-sign-out "ghealth" "\
@@ -264,7 +285,7 @@ Resets client so you can start with a different userid.
 ;;;;;;  gphoto-album-create gphoto-user-tagsearch gphoto-user-search
 ;;;;;;  gphoto-recent gphoto-community-search gphoto-download gphoto-view
 ;;;;;;  gphoto-tags gphoto-albums gphoto-feeds) "gphoto" "gphoto.el"
-;;;;;;  (19096 18402))
+;;;;;;  (20328 48785))
 ;;; Generated autoloads from gphoto.el
 
 (autoload 'gphoto-feeds "gphoto" "\
@@ -354,10 +375,11 @@ The retrieved entry is placed in a buffer ready for editing.
 
 ;;;### (autoloads (greader-re-authenticate greader-sign-in greader-sign-out
 ;;;;;;  greader-search greader-find-feeds greader-star greader-add-label
-;;;;;;  greader-untag-feed greader-tag-feed greader-title-feed greader-unsubscribe-feed
-;;;;;;  greader-subscribe-feed greader-opml greader-feed-list greader-subscriptions
+;;;;;;  greader-update-subscription greader-untag-feed greader-tag-feed
+;;;;;;  greader-title-feed greader-unsubscribe-feed greader-subscribe-feed
+;;;;;;  greader-opml greader-feed-list greader-subscriptions greader-subscription-list
 ;;;;;;  greader-preferences greader-reading-list) "greader" "greader.el"
-;;;;;;  (19491 53290))
+;;;;;;  (20328 48784))
 ;;; Generated autoloads from greader.el
 
 (autoload 'greader-reading-list "greader" "\
@@ -374,6 +396,11 @@ user.
 
 \(fn)" t nil)
 
+(autoload 'greader-subscription-list "greader" "\
+Return list of subscribed urls.
+
+\(fn)" nil nil)
+
 (autoload 'greader-subscriptions "greader" "\
 Return list of subscribed feeds.
 
@@ -414,6 +441,11 @@ Remove Tag from specified feed.
 
 \(fn FEED-URL)" t nil)
 
+(autoload 'greader-update-subscription "greader" "\
+Perform specified subscribe, unsubscribe, or edit action.
+
+\(fn FEED-URL ACTION)" nil nil)
+
 (autoload 'greader-add-label "greader" "\
 Add label to this item.
 
@@ -452,7 +484,7 @@ Reauthenticate current user.
 ;;;***
 
 ;;;### (autoloads (gsheet-sign-in gsheet-sign-out gsheet-sheets gsheet-fetch)
-;;;;;;  "gsheet" "gsheet.el" (18706 8727))
+;;;;;;  "gsheet" "gsheet.el" (20328 48785))
 ;;; Generated autoloads from gsheet.el
 
 (autoload 'gsheet-fetch "gsheet" "\
@@ -478,7 +510,7 @@ Resets client so you can start with a different userid.
 ;;;***
 
 ;;;### (autoloads (gskeleton-sign-in gskeleton-sign-out) "gskeleton"
-;;;;;;  "gskeleton.el" (19133 15361))
+;;;;;;  "gskeleton.el" (20328 48784))
 ;;; Generated autoloads from gskeleton.el
 
 (autoload 'gskeleton-sign-out "gskeleton" "\
@@ -496,7 +528,7 @@ Resets client so you can start with a different userid.
 ;;;### (autoloads (gtube-video-featured gtube-video-by-user gtube-video-popular
 ;;;;;;  gtube-video-playlist gtube-video-by-category-and-tag gtube-video-by-tag
 ;;;;;;  gtube-video-details gtube-user-friends gtube-user-favorites
-;;;;;;  gtube-user-profile) "gtube" "gtube.el" (18706 8727))
+;;;;;;  gtube-user-profile) "gtube" "gtube.el" (20328 48785))
 ;;; Generated autoloads from gtube.el
 
 (autoload 'gtube-user-profile "gtube" "\
@@ -561,9 +593,13 @@ Retrieved featured video list.
 ;;;***
 
 ;;;### (autoloads (gweb-my-address gweb-maps-reverse-geocode gweb-maps-geocode
-;;;;;;  gweb-google-at-point) "gweb" "gweb.el" (19358 34010))
+;;;;;;  gweb-google-at-point) "gweb" "gweb.el" (20328 48785))
 ;;; Generated autoloads from gweb.el
 
+(defsubst gweb-google-autocomplete-with-corpus (corpus) "\
+Read user input using Google Suggest for auto-completion.
+Uses specified corpus for prompting and suggest selection." (let* ((completer (intern (format "gweb-%s-suggest-completer" corpus))) (minibuffer-completing-file-name t) (completion-ignore-case t) (word (thing-at-point (quote word))) (query nil)) (unless (fboundp completer) (error "No  suggest handler for corpus %s" corpus)) (setq query (completing-read corpus completer nil nil word (quote gweb-history))) (pushnew query gweb-history) (g-url-encode query)))
+
 (autoload 'gweb-google-at-point "gweb" "\
 Google for term at point, and display top result succinctly.
 Attach URL at point so we can follow it later --- subsequent invocations of this command simply follow that URL.
@@ -595,12 +631,12 @@ Location address. Setting this updates gweb-my-location coordinates  via geocodi
 
 ;;;### (autoloads nil nil ("g-autogen.el" "g-cus-load.el" "g-load-path.el"
 ;;;;;;  "g-utils.el" "g.el" "gnotebook.el" "gwis.el" "indent-files.el"
-;;;;;;  "org2blogger.el") (19693 21462 523278))
+;;;;;;  "org2blogger.el") (20379 9055 284164))
 
 ;;;***
 
-;;;### (autoloads (g-app-view g-app-publish) "g-app" "g-app.el" (18827
-;;;;;;  26992))
+;;;### (autoloads (g-app-view g-app-publish) "g-app" "g-app.el" (20328
+;;;;;;  48785))
 ;;; Generated autoloads from g-app.el
 
 (autoload 'g-app-publish "g-app" "\
